@@ -1,4 +1,4 @@
-INSERT INTO device_types (id, name) values (1, 'Linux box'), (2, 'Advantech router'), (3, 'OpenWRT box'), (4, 'Teltonika router'), (5, 'CSTECH gateway'), (6, 'SNMP device');
+INSERT INTO device_types (id, name) values (1, 'Linux box'), (2, 'Advantech router'), (3, 'OpenWRT box'), (4, 'Teltonika router'), (5, 'CS-Tech gateway'), (6, 'SNMP device');
 
 INSERT INTO tunnel_op (id, name) VALUES (0, 'NONE'), (1, 'SETUP'), (2, 'SHUTDOWN'), (3, 'RESTART');
 
@@ -47,7 +47,7 @@ INSERT INTO graph_types(id, description) VALUES (1, "Bars"), (2, "Line");
 
 INSERT INTO graph_type_selections(id, graph_type, base, description) VALUES (1, 1, 0, "Bars with base at 0"), (2, 1, -120, "Bars with base at -120"), (3, 2, 0, "Line");
 
-INSERT INTO device_os_types (id, name, dev_type, directory_name, file_extension) VALUES (1, 'Unknown', NULL, NULL, NULL), (2, 'Generic Linux', NULL, NULL, NULL), (3, 'ICR OS', 2, 'conelos', '.bin'), (4, 'Debian Linux', NULL, NULL, NULL), (5, 'OpenWRT', NULL, NULL, NULL), (6, 'RutOS', 4, 'rutos', '.bin'), (7, 'CSTECH Linux', 5, 'cstech', '.bin');
+INSERT INTO device_os_types (id, name, dev_type, directory_name, file_extension) VALUES (1, 'Unknown', NULL, NULL, NULL), (2, 'Generic Linux', NULL, NULL, NULL), (3, 'ICR OS', 2, 'conelos', '.bin'), (4, 'Debian Linux', NULL, NULL, NULL), (5, 'OpenWRT', NULL, NULL, NULL), (6, 'RutOS', 4, 'rutos', '.bin'), (7, 'CS-Tech Linux', 5, 'cstech', '.bin');
 
 INSERT INTO device_os_versions (id, os_type, description, keep) VALUES
 (1, 3, '6.2.0', TRUE);
@@ -194,6 +194,7 @@ INSERT INTO log_event_type (id, source, name) VALUES
 (114, 2, 'FW file uploaded'),
 (151, 2, 'Monitoring group update'),
 (152, 2, 'CFG group update'),
+(153, 2, 'Button event'),
 (301, 3, 'Script'),
 (302, 3, 'Critical error (script)'),
 (303, 3, 'Recycling requested'),
@@ -237,45 +238,46 @@ INSERT INTO data_change_source (id, name) VALUES (1, 'server'), (2, 'script'), (
 
 INSERT INTO alert_table_selection (id, table_selection) VALUES (0, 'invalid'), (1, 'device_sync_statuses'), (2, 'liveness_time'), (3, 'liveness_misscount'), (4, 'device_os_versions');
 
-INSERT INTO alert_target_spec (id, name, valtype, seltype, hint, custom) VALUES
-(0, 'Invalid target', 1, 0, '', FALSE),
-(1, 'SYNC status', 6, 1, 'Recommended operators: =, !=', FALSE),
-(2, 'Data age', 6, 2, 'Recommended operators: =, >', FALSE),
-(3, 'Missed contacts', 6, 3, 'Recommended operators: =, >', FALSE),
-(4, 'Input Voltage', 2, 0, 'Recommended to use with voltage interval', FALSE),
-(5, 'Device Temperature', 2, 0, 'Recommended to use with temperature interval', FALSE),
-(6, 'FW version', 6, 4, 'Recommended operators: =, !=', FALSE),
-(7, 'Allocable memory', 1, 0, 'Includes both free and cache memory, use < operator', FALSE),
-(8, '# of running processes', 1, 0, 'Highly fluctuable value', FALSE),
-(9, 'Root FS free space', 1, 0, 'In kilobytes, 0 = device root FS full', FALSE),
-(10, 'AVG load 1 minute', 2, 0, '60-second load. Note data sampling may be > 1 minute', FALSE),
-(11, 'AVG load 5 minutes', 2, 0, 'Last 5 minutes load', FALSE),
-(12, 'AVG load 15 minutes', 2, 0, 'Last 15 minutes load', FALSE),
-(13, 'New reboots', 1, 0, 'Use > 0 to get alerted on every reboot', FALSE),
-(14, 'Signal strenght', 1, 0, 'Recommended operators: =, <, >', FALSE),
-(15, 'Signal quality', 1, 0, 'Recommended operators: =, <, >', FALSE),
-(16, 'Custom number 1', 1, 0, 'Custom integer number 1', TRUE),
-(17, 'Custom number 2', 1, 0, 'Custom integer number 2', TRUE),
-(18, 'Custom number 3', 1, 0, 'Custom integer number 3', TRUE),
-(19, 'Custom number 4', 1, 0, 'Custom integer number 4', TRUE),
-(20, 'Custom number 5', 1, 0, 'Custom integer number 5', TRUE),
-(21, 'Custom number 6', 1, 0, 'Custom integer number 6', TRUE),
-(22, 'Custom number 7', 1, 0, 'Custom integer number 7', TRUE),
-(23, 'Custom number 8', 1, 0, 'Custom integer number 8', TRUE),
-(24, 'Custom number 9', 1, 0, 'Custom integer number 9', TRUE),
-(25, 'Custom real 1', 2, 0, 'Custom real number 1', TRUE),
-(26, 'Custom real 2', 2, 0, 'Custom real number 2', TRUE),
-(27, 'Custom real 3', 2, 0, 'Custom real number 3', TRUE),
-(28, 'Custom real 4', 2, 0, 'Custom real number 4', TRUE),
-(29, 'Custom real 5', 2, 0, 'Custom real number 5', TRUE),
-(30, 'Custom real 6', 2, 0, 'Custom real number 6', TRUE),
-(31, 'Custom real 7', 2, 0, 'Custom real number 7', TRUE),
-(32, 'Custom real 8', 2, 0, 'Custom real number 8', TRUE),
-(33, 'Custom real 9', 2, 0, 'Custom real number 9', TRUE);
+INSERT INTO alert_target_spec (id, name, valtype, seltype, hint, display_order, custom) VALUES
+(0, 'Invalid target', 1, 0, '', 0, FALSE),
+(1, 'SYNC status', 6, 1, 'Recommended operators: =, !=', 1, FALSE),
+(2, 'Data age', 6, 2, 'Recommended operators: =, >', 2, FALSE),
+(3, 'Missed contacts', 6, 3, 'Recommended operators: =, >', 3, FALSE),
+(4, 'Input Voltage', 2, 0, 'Recommended to use with voltage interval', 4, FALSE),
+(5, 'Device Temperature', 2, 0, 'Recommended to use with temperature interval', 5, FALSE),
+(6, 'FW version', 6, 4, 'Recommended operators: =, !=', 6, FALSE),
+(7, 'Allocable memory', 1, 0, 'Includes both free and cache memory, use < operator', 7, FALSE),
+(8, '# of running processes', 1, 0, 'Highly fluctuable value', 8, FALSE),
+(9, 'Root FS free space', 1, 0, 'In kilobytes, 0 = device root FS full', 9, FALSE),
+(10, 'AVG load 1 minute', 2, 0, '60-second load. Note data sampling may be > 1 minute', 10, FALSE),
+(11, 'AVG load 5 minutes', 2, 0, 'Last 5 minutes load', 11, FALSE),
+(12, 'AVG load 15 minutes', 2, 0, 'Last 15 minutes load', 12, FALSE),
+(13, 'New reboots', 1, 0, 'Use > 0 to get alerted on every reboot', 13, FALSE),
+(14, 'Signal strenght', 1, 0, 'Recommended operators: =, <, >', 14, FALSE),
+(15, 'Signal quality', 1, 0, 'Recommended operators: =, <, >', 15, FALSE),
+(16, 'Custom number 1', 1, 0, 'Custom integer number 1', 17, TRUE),
+(17, 'Custom number 2', 1, 0, 'Custom integer number 2', 18, TRUE),
+(18, 'Custom number 3', 1, 0, 'Custom integer number 3', 19, TRUE),
+(19, 'Custom number 4', 1, 0, 'Custom integer number 4', 20, TRUE),
+(20, 'Custom number 5', 1, 0, 'Custom integer number 5', 21, TRUE),
+(21, 'Custom number 6', 1, 0, 'Custom integer number 6', 22, TRUE),
+(22, 'Custom number 7', 1, 0, 'Custom integer number 7', 23, TRUE),
+(23, 'Custom number 8', 1, 0, 'Custom integer number 8', 24, TRUE),
+(24, 'Custom number 9', 1, 0, 'Custom integer number 9', 25, TRUE),
+(25, 'Custom real 1', 2, 0, 'Custom real number 1', 26, TRUE),
+(26, 'Custom real 2', 2, 0, 'Custom real number 2', 27, TRUE),
+(27, 'Custom real 3', 2, 0, 'Custom real number 3', 28, TRUE),
+(28, 'Custom real 4', 2, 0, 'Custom real number 4', 29, TRUE),
+(29, 'Custom real 5', 2, 0, 'Custom real number 5', 30, TRUE),
+(30, 'Custom real 6', 2, 0, 'Custom real number 6', 31, TRUE),
+(31, 'Custom real 7', 2, 0, 'Custom real number 7', 32, TRUE),
+(32, 'Custom real 8', 2, 0, 'Custom real number 8', 33, TRUE),
+(33, 'Custom real 9', 2, 0, 'Custom real number 9', 34, TRUE),
+(34, 'Active SIM', 3, 0, 'Active SIM string', 16, FALSE);
 
 -- (1, 'int'), (2, 'double'), (3, 'string'),
 
-INSERT INTO alert_target_map (target_spec, target_type) VALUES (0, 0), (1, 4), (2, 1), (2, 4), (3, 1), (3, 4), (4, 1), (4, 4), (5, 1), (5, 4), (6, 1), (6, 4), (7, 1), (7, 4), (8, 1), (8, 4), (9, 1), (9, 4), (10, 1), (10, 4), (11, 1), (11, 4), (12, 1), (12, 4), (13, 1), (13, 4), (14, 1), (14, 4), (15, 1), (15, 4), (16, 1), (16, 4), (17, 1), (17, 4), (18, 1), (18, 4), (19, 1), (19, 4), (20, 1), (20, 4), (21, 1), (21, 4), (22, 1), (22, 4), (23, 1), (23, 4), (24, 1), (24, 4), (25, 1), (25, 4), (26, 1), (26, 4), (27, 1), (27, 4), (28, 1), (28, 4), (29, 1), (29, 4), (30, 1), (30, 4), (31, 1), (31, 4), (32, 1), (32, 4), (33, 1), (33, 4);
+INSERT INTO alert_target_map (target_spec, target_type) VALUES (0, 0), (1, 4), (2, 1), (2, 4), (3, 1), (3, 4), (4, 1), (4, 4), (5, 1), (5, 4), (6, 1), (6, 4), (7, 1), (7, 4), (8, 1), (8, 4), (9, 1), (9, 4), (10, 1), (10, 4), (11, 1), (11, 4), (12, 1), (12, 4), (13, 1), (13, 4), (14, 1), (14, 4), (15, 1), (15, 4), (16, 1), (16, 4), (17, 1), (17, 4), (18, 1), (18, 4), (19, 1), (19, 4), (20, 1), (20, 4), (21, 1), (21, 4), (22, 1), (22, 4), (23, 1), (23, 4), (24, 1), (24, 4), (25, 1), (25, 4), (26, 1), (26, 4), (27, 1), (27, 4), (28, 1), (28, 4), (29, 1), (29, 4), (30, 1), (30, 4), (31, 1), (31, 4), (32, 1), (32, 4), (33, 1), (33, 4), (34, 1), (34, 4);
 
 INSERT INTO product_conf (name, system, valtype, intval, floatval, strval) VALUES
 ('ExternalURL', false, 3, 0, 0, '127.0.0.1'),
