@@ -836,6 +836,7 @@ value INT,
 source INT NOT NULL DEFAULT 1,
 extra_id INT,
 msg VARCHAR(256),
+user_id INT DEFAULT NULL,
 time DATETIME DEFAULT CURRENT_TIMESTAMP,
 FOREIGN KEY (evtype) REFERENCES log_event_type(id),
 FOREIGN KEY (source) REFERENCES log_event_source(id)
@@ -871,6 +872,7 @@ valtype SMALLINT UNSIGNED NOT NULL DEFAULT 1,
 seltype SMALLINT DEFAULT 0,
 hint VARCHAR(64),
 custom BOOLEAN DEFAULT FALSE,
+display_order SMALLINT UNSIGNED NOT NULL DEFAULT 0,
 FOREIGN KEY (valtype) REFERENCES typetable_value_types(id),
 FOREIGN KEY (seltype) REFERENCES alert_table_selection(id)
 );
@@ -898,6 +900,7 @@ oper_first SMALLINT DEFAULT 0,
 oper_second SMALLINT DEFAULT 0,
 num_first DOUBLE DEFAULT 0,
 num_second DOUBLE DEFAULT 0,
+string_first VARCHAR(256) DEFAULT NULL,
 last_trigger_time DATETIME DEFAULT NULL,
 last_notification_time DATETIME,
 last_review_time DATETIME,
