@@ -24,6 +24,7 @@ BACKUP_RESTORE=0
 USE_SSL=1
 GET_NONDEB=0
 UPGRADING="${UPGRADING:-0}"
+FORCE_DB_CREATION="${FORCE_DB_CREATION:-}"
 PORT_OFFSET="${PORT_OFFSET:-0}"
 DWARFGD_PORT="${DWARFGD_PORT:-8484}"
 LICENSE_FILE="${LICENSE_FILE:-}"
@@ -33,10 +34,11 @@ NEW_DB=""
 SKIP_START=0
 
 export UPGRADING
+export FORCE_DB_CREATION
 
 print_help() {
 	echo -e "\nHi there, this is $NAME deploy script.\nThe purpose of this script is to deploy $NAME on your server,\npossibly wiping out existing installation or retaining current data.\n\nAllowed parameters:\n"
-	echo -e "\t$PARAM_DOMAIN <domain> ... IF USING, PUT THIS PARAMETER *FIRST*. Install $NAME for a particular domain. This affects apache2 config and DB name."
+	echo -e "\t$PARAM_DOMAIN <domain> ... IF USING, PUT THIS PARAMETER *FIRST*. Install $NAME for a particular domain. This affects apache2 config and DB name. You need to use this parameter or specify IP address by 'export CERTDOMAIN=\"1.2.3.4\"' before calling the install script."
 	echo -e "\t$PARAM_NONDEB ... After regular installation finishes, attempt to install also extra SW components outside of the Debian archive. These components are usually installed by dwarfg_grafint (Grafana) and dwarfg_inst_pyext (Python PureSNNMP library to enable SNMP Gateway and SSHWifty web-based terminal to allow access to the SSH tunnel directly from the browser). Read respective dwarfg_ commands help to find out how to install this when your deployment server is offline without access to Internet. Please note that in the case of multi-deployment machine, only one deployment can have automatic integration with Grafana enabled."
 	echo -e "\t$PARAM_LICFILE <license_file_ABSOLUTE_path> ... Use license_file_path license instead of the one bundled in the package. NOTE: license check tool requires some libraries that are e.g. installed during deployment (if you have not installed $NAME on this machine, the deployment may fail as the library is not present. Either install the libraries manually, or install/uninstall $NAME without using this parameter first)"
 	echo -e "\t$PARAM_OFFSET <number> ... For usage together with domain - a number to offset tunnel ports with (usually a 100 with every additional domain). NOTE: this is now set automatically, no need to specify this explicitely."
@@ -224,6 +226,9 @@ if [ $# -ne 0 ] ; then
 	process_params "$@"
 fi
 read_defs
+[[ -z "$DOMAIN" && -z "$EXTERNURL" && -z "$CERTDOMAIN" ]] && {
+	fail_fat "Both DOMAIN and EXTERNURL are empty. Use $PARAM_DOMAIN or export IP address as CERTDOMAIN variable."
+}
 IFS='.' read -a DEBIAN_VERSION < /etc/debian_version
 MYID=$($C_ID -u)
 [ 0 -ne "$MYID" ] && fail_fat "$NAME deploy script must run under root."
