@@ -33,9 +33,11 @@ PARAM_SERVID="--servid"
 PARAM_BONLY="--bonly"
 PARAM_RONLY="--ronly"
 PARAM_DOMAIN="--domain"
+PARAM_SECURITY="--agent-security"
 PARAM_LICFILE="--license"
 PARAM_OFFSET="--offset"
 PARAM_SERVSSH="--servsshport"
+PARAM_NONDEB="--nondeb"
 PARAM_ADMPWD="--admpwd"
 PARAM_ADMNAME="--admname"
 PARAM_OPERPWD="--operpwd"
@@ -146,14 +148,7 @@ read_defs() {
 	. "$MYDIR/$BASEFUNCS" || { echo "Fatal: Basic functions ($MYDIR/$BASEFUNCS) not found." >&2; exit 1; }
 }
 
-# following functions serve mostly for updating variables in mid-deploy. It could be simplified considerably by reducing C+P
-update_domain() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating domain in $MYDIR/$BASEDEFS..."
-	$C_SED -i --follow-symlinks "s/^\(DOMAIN\)=.*/\1=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
+# following functions serve mostly for updating variables in mid-deploy.
 
 update_stuff_here() {
 	[ $# -eq 2 ] || {
@@ -171,7 +166,7 @@ update_install_paths() {
 		echo "Install paths update: need path to target directory ($1 is not an accessible directory)." >&2
 		return 1
 	}
-	echo "Updating INSTALL_PATH and INSTALL_DIR in $1..."
+	echo "Updating INSTALL_PATH, INSTALL_DIR and PYTON_VENV in $1..."
 	opwd="$(pwd)"
 	cd "$1" || {
 		echo "Unable to change directory to $1" >&2
@@ -179,22 +174,77 @@ update_install_paths() {
 	}
 	update_stuff_here "INSTALL_PATH" "$BINDIR"
 	update_stuff_here "INSTALL_DIR" "$DWARFG_NAM"
+	update_stuff_here "PYTHON_VENV" "$PYTHON_VENV"
 	cd "$opwd"
 	return 0
 }
 
-update_sysctl() {
+update_basedefs() {
 	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating systemctl path in $MYDIR/$BASEDEFS... "
-	$C_SED -i --follow-symlinks "s#^\(SYSCTLPATH\)=.*#\1=\"$1\"#" "$MYDIR/$BASEDEFS"
+	[[ $# -eq 3 && "$3" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
+	echo "Updating $1 in $MYDIR/$BASEDEFS ..."
+	$C_SED -i --follow-symlinks "s#^\($1\)=.*#\1=\"$2\"#" "$MYDIR/$BASEDEFS"
+}
+
+update_sysctl() {
+	update_basedefs "SYSCTLPATH" "$@"
 }
 
 update_usessl() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating USE_SSL in $MYDIR/$BASEDEFS..."
-	$C_SED -i --follow-symlinks "s/^\(USE_SSL\)=.*/\1=\"$1\"/" "$MYDIR/$BASEDEFS"
+	update_basedefs "USE_SSL" "$@"
+}
+
+update_domain() {
+	update_basedefs "DOMAIN" "$@"
+}
+
+update_servid() {
+	update_basedefs "SERVID" "$@"
+}
+
+update_scdkey() {
+	update_basedefs "SCDKEY" "$@"
+}
+
+update_externurl() {
+	update_basedefs "EXTERNURL" "$@"
+}
+
+update_offset() {
+	update_basedefs "PORT_OFFSET" "$@"
+}
+
+update_servssh() {
+	update_basedefs "SERV_TUNSSH_PORT" "$@"
+}
+
+update_daemon_port() {
+	update_basedefs "DWARFG_PORT" "$@"
+}
+
+update_agent_security() {
+	update_basedefs "AGENT_FORCED_SECURITY" "$@"
+}
+
+prep_servid() {
+	local NEWSERVID
+	if [ -z "$SERVID" ] ; then
+		NEWSERVID="$(cat /proc/sys/kernel/random/uuid)"
+	else
+		NEWSERVID="$SERVID"
+	fi
+	update_basedefs "SERVID" "$NEWSERVID" "$ORIG_DEPLOY_STR"
+}
+
+prep_scdkey() {
+	local NEWSCDK
+	if [ -z "$SCDKEY" ] ; then
+		NEWSCDK="$(cat /proc/sys/kernel/random/uuid | tr -d '-')"
+	else
+		NEWSCDK="$SCDKEY"
+	fi
+	update_basedefs "SCDKEY" "$NEWSCDK" "$ORIG_DEPLOY_STR" >/dev/null
+	echo $NEWSCDK
 }
 
 update_site_var() {
@@ -217,7 +267,7 @@ update_site_var() {
 				echo "Creting new $NAME site config..."
 				echo "# Do not edit this file. It contains site-wide configuration for all your $NAME deployments and improper directive or syntax error here may result in partial or complete malfunction of one or all of your $NAME deployments" >"$DWARFG_SITECONF"
 				echo "$1=\"$UPDVAL\"" >>"$DWARFG_SITECONF"
-				chown $APPUSER "$DWARFG_SITECONF"
+				$C_CHOWN $APPUSER "$DWARFG_SITECONF"
 				chmod =600 "$DWARFG_SITECONF"
 			fi
 			;;
@@ -248,49 +298,6 @@ new_gradmpass() {
 	update_site_var "GRADMPASS" "$GRADMPASS"
 }
 
-update_servid() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating servid in $MYDIR/$BASEDEFS to $1..."
-	$C_SED -i --follow-symlinks "s/^SERVID=.*/SERVID=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
-update_scdkey() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating scdkey in $MYDIR/$BASEDEFS to $1..."
-	$C_SED -i --follow-symlinks "s/^SCDKEY=.*/SCDKEY=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
-update_externurl() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating external URL in $MYDIR/$BASEDEFS to $1..."
-	$C_SED -i --follow-symlinks "s/^EXTERNURL=.*/EXTERNURL=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
-prep_servid() {
-	local NEWSERVID
-	if [ -z "$SERVID" ] ; then
-		NEWSERVID="$(cat /proc/sys/kernel/random/uuid)"
-	else
-		NEWSERVID="$SERVID"
-	fi
-	echo "Updating servid in $BINDIR/$BASEDEFS (orig: \"$SERVID\"; new: \"$NEWSERVID\") ..."
-	$C_SED -i --follow-symlinks "s/^SERVID=.*/SERVID=\"$NEWSERVID\"/" "$BINDIR/$BASEDEFS"
-}
-
-prep_scdkey() {
-	local NEWSCDK
-	if [ -z "$SCDKEY" ] ; then
-		NEWSCDK="$(cat /proc/sys/kernel/random/uuid | tr -d '-')"
-	else
-		NEWSCDK="$SCDKEY"
-	fi
-	$C_SED -i --follow-symlinks "s/^SCDKEY=.*/SCDKEY=\"$NEWSCDK\"/" "$BINDIR/$BASEDEFS"
-	echo $NEWSCDK
-}
-
 add_app_group() {
 	"$C_GETENT" group "$APPGROUP" && return 0
 	"$C_ADDGROUP" --system "$APPGROUP" || return 1
@@ -299,7 +306,7 @@ add_app_group() {
 
 add_app_user() {
 	"$C_ID" -u "$APPUSER" >/dev/null 2>&1 && return 0
-	"$C_ADDUSER" --system --ingroup "$APPGROUP" --disabled-password --no-create-home --shell=/bin/sh --home "$DWARFG_HOME" "$APPUSER" || return 1
+	"$C_ADDUSER" --system --ingroup "$APPGROUP" --disabled-password --no-create-home --shell=/bin/bash --home "$DWARFG_HOME" "$APPUSER" || return 1
 	return 0
 }
 
@@ -319,23 +326,28 @@ add_app_home() {
 }
 
 add_app_service() {
-	"$C_CP" "$BINDIR"/$SHORTNAME.service /etc/systemd/system/"${DWARFG_NAM}".service || return 1
-#	"$C_SED" -i "s#/opt/${SHORTNAME}#$BINDIR#" /etc/systemd/system/"${DWARFG_NAM}".service || return 1
-#	"$C_SED" -i "s#/srv/${SHORTNAME}#$SRVDIR#" /etc/systemd/system/"${DWARFG_NAM}".service || return 1
+	for i in ".service" "_${SNMP_GW}.service"; do
+		"$C_LN" "$BINDIR/$SHORTNAME$i" /etc/systemd/system/"${DWARFG_NAM}$i" || return 1
+	done
 	return 0
 }
 
 add_app_sudoers() {
 	echo -e "Cmnd_Alias NOTIFY_CMD_${DWARFG_DBN^^}=/usr/bin/php $BINDIR/notifier/bin/console app\:email-notification *,/usr/bin/php $BINDIR/notifier/bin/console app\:slack-notification *" >/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} is-active ${DWARFG_NAM}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
+	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} is-active ${DWARFG_NAM}_${SNMP_GW}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} restart ${DWARFG_NAM}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
+	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} restart ${DWARFG_NAM}_${SNMP_GW}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} start ${DWARFG_NAM}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
+	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} start ${DWARFG_NAM}_${SNMP_GW}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
+	echo -e "$WWWUSER\tALL=NOPASSWD:${C_SYSTEMCTL} stop ${DWARFG_NAM}_${SNMP_GW}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=($APPUSER) NOPASSWD:$BINDIR/prep_custom_agent.sh" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=($APPUSER) NOPASSWD:$BINDIR/exchange_server_ip.sh" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=($APPUSER) NOPASSWD:$BINDIR/licman" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$APPUSER\tALL=NOPASSWD:${C_SYSTEMCTL} restart apache2.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$APPUSER\tALL=NOPASSWD:${C_SYSTEMCTL} reload apache2.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$APPUSER\tALL=NOPASSWD:${C_SYSTEMCTL} restart ${DWARFG_NAM}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
+	echo -e "$APPUSER\tALL=NOPASSWD:${C_SYSTEMCTL} restart ${DWARFG_NAM}_${SNMP_GW}.service" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$APPUSER\tALL=NOPASSWD:${C_SS}" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=($APPUSER) NOPASSWD:$BINDIR/grab_logs.sh" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
 	echo -e "$WWWUSER\tALL=($APPUSER) NOPASSWD:NOTIFY_CMD_${DWARFG_DBN^^}" >>/etc/sudoers.d/"${DWARFG_DBN}" || return 1
@@ -357,10 +369,19 @@ apa_servsite() {
 }
 
 create_app_fwdir() {
-	if [ ! -d "$DWARFG_CACHE/$FW_FLAVORS" ] ; then # create system-wide cache directory if not existing
-		"$C_MKDIR" -p "$DWARFG_CACHE/$FW_FLAVORS" || return 1
-		"$C_CHOWN" -R "$APPUSER" "$DWARFG_CACHE" || return 1
-	fi
+	for i in $FW_FLAVORS; do
+		if [ ! -d "$DWARFG_CACHE/$i" ] ; then # create system-wide cache directory if not existing
+			"$C_MKDIR" -p "$DWARFG_CACHE/$i" || return 1
+			"$C_CHOWN" -R "$APPUSER" "$DWARFG_CACHE" || return 1
+		fi
+	done
+	return 0
+}
+
+run_snmpgw_svc() {
+	"$C_SYSTEMCTL" enable --now "${DWARFG_NAM}_${SNMP_GW}.service" || return 1
+	"$C_SLEEP" 4 || return 1
+	"$C_SYSTEMCTL" --output=short -n 0 --no-pager status "${DWARFG_NAM}_${SNMP_GW}.service" || return 1
 	return 0
 }
 
@@ -371,27 +392,6 @@ run_app_svc() {
 	return 0
 }
 
-update_offset() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR=$BINDIR
-	echo "Updating offset in $MYDIR/$BASEDEFS ..."
-	$C_SED -i --follow-symlinks "s/^\(PORT_OFFSET\)=.*/\1=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
-update_servssh() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR="$BINDIR"
-	echo "Updating serv ssh port in $MYDIR/$BASEDEFS..."
-	$C_SED -i --follow-symlinks "s/^\(SERV_TUNSSH_PORT\)=.*/\1=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
-update_daemon_port() {
-	local MYDIR="$DIR"
-	[[ $# -eq 2 && "$2" == "$ORIG_DEPLOY_STR" ]] && MYDIR="$BINDIR"
-	echo "Updating $NAME daemon local port in $MYDIR/$BASEDEFS to $1..."
-	$C_SED -i --follow-symlinks "s/^\(DWARFG_PORT\)=.*/\1=\"$1\"/" "$MYDIR/$BASEDEFS"
-}
-
 # mid-deploy Dwarfg wipeout
 wipeout() {
 	local ORIGCLEANUP=0
@@ -634,7 +634,7 @@ set_phpini_var() {
 	for i in $(find /etc/php/ -iname "php.ini" | grep apache2); do
 		if grep "^[ \t]*$1[ \t]*=" "$i" >/dev/null; then
 			# present, update the value...
-			if sed -i "0,/^[ \t]*;[ \t]*$1[ \t]*=/s/^[ \t]*;[ \t]*$1[ \t]*=.*/$1 = $2/" $i 2>/dev/null; then
+			if sed -i "0,/^[ \t]*$1[ \t]*=/s/^[ \t]*$1[ \t]*=.*/$1 = $2/" $i 2>/dev/null; then
 				echo "Replaced PHP configuration value $1 to value $2 in $i ..."
 			else
 				echo "Failed to replace PHP configuration value $1 in $i ..."
