@@ -51,18 +51,19 @@ MYOXPWD=$(pwd)
 	[ $? -eq 0 ] || fail_fat "Unable to generate SCDKEY"
 }
 cd "$BINDIR" || fail_fat "Cannot change directory to $BINDIR"
-[ 0 -eq "$UPGRADING" ] && {
+[[ 0 -eq "$UPGRADING" || -n "$FORCE_DB_CREATION" ]] && {
 	prep_db || fail_fat "Unable to create database ($DWARFG_DBN) or user."
 }
-CNTR=5
-if [ 0 -eq "$UPGRADING" ] ; then
+CNTR=6
+if [[ 0 -eq "$UPGRADING" || -n "$FORCE_DB_CREATION" ]] ; then
 	echo "Populating $NAME database..."
 	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_init_scheme.sql" || fail_fat "Not able to initialize $NAME database scheme (1/$CNTR)."
 	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_init_basedata.sql" || fail_fat "Not able to initialize $NAME database base data (2/$CNTR)."
 	# handle also all upgrade scripts...
 	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_init_verdata.sql" || fail_fat "Not able to initialize $NAME database version data (3/$CNTR)."
 	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_init_guidata.sql" || fail_fat "Not able to initialize $NAME database gui data (4/$CNTR)."
-	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_init_default_alerts.sql" || fail_fat "Not able to initialize $NAME database default alerts (5/$CNTR)"
+	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_rebuild_device_view.sql" || fail_fat "Not able to initialize $NAME database device view (5/$CNTR)."
+	$C_MYSQL $MYSQOPT "$DWARFG_DBN" < "$BINDIR/db_init_default_alerts.sql" || fail_fat "Not able to initialize $NAME database default alerts (6/$CNTR)"
 else
 	CNTR=2
 fi
@@ -74,7 +75,7 @@ if [[ -z "$CERTDOMAIN" && -n "$EXTERNURL" ]] ; then
 	CERTDOMAIN="$EXTERNURL"
 	export CERTDOMAIN
 fi
-[ 0 -eq "$UPGRADING" ] && {
+[[ 0 -eq "$UPGRADING" || -n "$FORCE_DB_CREATION" ]] && {
 	if [ -n "$CERTDOMAIN" ] ; then
 		$C_MYSQL $MYSQOPT "$DWARFG_DBN"<<EOF
 UPDATE product_conf SET strval="$CERTDOMAIN" WHERE name='ExternalURL';
@@ -130,14 +131,14 @@ enable_ffi || fail_fat "Unable to enable FFI for PHP. Contact support or setup m
 set_phpini_var "max_input_vars" "20000" || fail_fat "Unable to configure max_input_vars in php.ini."
 set_phpini_var "upload_max_filesize" "40M" || fail_fat "Unable to configure upload_max_filesize in php.ini."
 set_phpini_var "post_max_size" "41M" || fail_fat "Unable to configure post_max_size in php.ini."
-if [ 0 -eq "$UPGRADING" ] ; then
+if [[ 0 -eq "$UPGRADING" || -n "$FORCE_DB_CREATION" ]] ; then
 	echo "UPDATE product_conf set strval=\"$C_SYSTEMCTL\" where name='SysctlPath';" | $C_MYSQL $MYSQOPT "$DWARFG_DBN" || fail_nof "Warning: unable to update systemctl path. If default path does not fit, restarting $NAME service from GUI will not work."
 	update_sysctl "$C_SYSTEMCTL"
 fi
 MYPWD=$(pwd)
 $C_MKDIR -m 777 -p "$WEBVARDIR/cache"
 cd "$GUIDIR"
-[ 0 -eq "$UPGRADING" ] && {
+[[ 0 -eq "$UPGRADING" || -n "$FORCE_DB_CREATION" ]] && {
 	$C_SUDO -u "$WWWUSER" "$C_PHP" bin/console user:create "$ADMNAME" "$ADMPWD" ROLE_SUPER_ADMIN || fail_fat "Unable to add admin user to GUI"
 	$C_SUDO -u "$WWWUSER" "$C_PHP" bin/console user:create "$OPERNAME" "$OPERPWD" ROLE_ADMIN -a false || fail_fat "Unable to add operator user to GUI"
 }
