@@ -19,22 +19,23 @@ interface EditableInterface
     /**
      * @return string
      */
-    public function getType();
+    public function getType(): string;
 
-    /**
-     * Checks whether the object may be editable.
-     *
-     * @return bool
-     */
-    public function callEditableIfClosure(array $row = []);
+	/**
+	 * Checks whether the object may be editable.
+	 *
+	 * @param array $row
+	 * @return bool
+	 */
+    public function callEditableIfClosure(array $row = []): bool;
 
     /**
      * @return string
      */
-    public function getPk();
+    public function getPk(): string;
 
     /**
      * @return string
      */
-    public function getEmptyText();
+    public function getEmptyText(): string;
 }
