@@ -22,7 +22,7 @@ interface FilterInterface
     /**
      * @return string
      */
-    public function getTemplate();
+    public function getTemplate(): string;
 
     /**
      * Add an and condition.
@@ -33,5 +33,5 @@ interface FilterInterface
      *
      * @return Andx
      */
-    public function addAndExpression(Andx $andExpr, QueryBuilder $qb, $searchField, $searchValue, $searchTypeOfField, &$parameterCounter);
+    public function addAndExpression(Andx $andExpr, QueryBuilder $qb, $searchField, $searchValue, $searchTypeOfField, &$parameterCounter): Andx;
 }
