@@ -12,6 +12,7 @@
 namespace Sg\DatatablesBundle\Datatable\Filter;
 
 use Doctrine\ORM\Query\Expr\Andx;
+use Doctrine\ORM\Query\Expr\Composite;
 use Doctrine\ORM\QueryBuilder;
 
 class TextFilter extends AbstractFilter
@@ -23,16 +24,16 @@ class TextFilter extends AbstractFilter
     /**
      * {@inheritdoc}
      */
-    public function getTemplate()
-    {
+    public function getTemplate(): string
+	{
         return '@SgDatatables/filter/input.html.twig';
     }
 
     /**
      * {@inheritdoc}
      */
-    public function addAndExpression(Andx $andExpr, QueryBuilder $qb, $searchField, $searchValue, $searchTypeOfField, &$parameterCounter)
-    {
+    public function addAndExpression(Composite $andExpr, QueryBuilder $qb, $searchField, $searchValue, $searchTypeOfField, &$parameterCounter): Andx
+	{
         return $this->getExpression($andExpr, $qb, $this->searchType, $searchField, $searchValue, $searchTypeOfField, $parameterCounter);
     }
 
