@@ -31,7 +31,7 @@ class Options
      *
      * @var array|int|null
      */
-    protected $deferLoading;
+    protected array|int|null $deferLoading;
 
     /**
      * Initial paging start point.
@@ -40,7 +40,7 @@ class Options
      *
      * @var int|null
      */
-    protected $displayStart;
+    protected ?int $displayStart;
 
     /**
      * Define the table control elements to appear on the page and in what order.
@@ -49,7 +49,7 @@ class Options
      *
      * @var string|null
      */
-    protected $dom;
+    protected ?string $dom;
 
     /**
      * Change the options in the page length select list.
@@ -58,7 +58,7 @@ class Options
      *
      * @var array|null
      */
-    protected $lengthMenu;
+    protected ?array $lengthMenu;
 
     /**
      * Initial order (sort) to apply to the table.
@@ -67,7 +67,7 @@ class Options
      *
      * @var array|null
      */
-    protected $order;
+    protected ?array $order;
 
     /**
      * Control which cell the order event handler will be applied to in a column.
@@ -76,7 +76,7 @@ class Options
      *
      * @var bool|null
      */
-    protected $orderCellsTop;
+    protected ?bool $orderCellsTop;
 
     /**
      * Highlight the columns being ordered in the table's body.
@@ -85,7 +85,7 @@ class Options
      *
      * @var bool|null
      */
-    protected $orderClasses;
+    protected ?bool $orderClasses;
 
     /**
      * Ordering to always be applied to the table.
@@ -93,7 +93,7 @@ class Options
      *
      * @var array|null
      */
-    protected $orderFixed;
+    protected ?array $orderFixed;
 
     /**
      * Multiple column ordering ability control.
@@ -102,7 +102,7 @@ class Options
      *
      * @var bool|null
      */
-    protected $orderMulti;
+    protected ?bool $orderMulti;
 
     /**
      * Change the initial page length (number of rows per page).
@@ -111,7 +111,7 @@ class Options
      *
      * @var int|null
      */
-    protected $pageLength;
+    protected ?int $pageLength;
 
     /**
      * Pagination button display options.
@@ -127,7 +127,7 @@ class Options
      *
      * @var string|null
      */
-    protected $pagingType;
+    protected ?string $pagingType;
 
     /**
      * Display component renderer types.
@@ -135,7 +135,7 @@ class Options
      *
      * @var string|null
      */
-    protected $renderer;
+    protected ?string $renderer;
 
     /**
      * Retrieve an existing DataTables instance.
@@ -144,7 +144,7 @@ class Options
      *
      * @var bool|null
      */
-    protected $retrieve;
+    protected ?bool $retrieve;
 
     /**
      * Data property name that DataTables will use to set tr element DOM IDs.
@@ -153,7 +153,7 @@ class Options
      *
      * @var string|null
      */
-    protected $rowId;
+    protected ?string $rowId;
 
     /**
      * Allow the table to reduce in height when a limited number of rows are shown.
@@ -162,7 +162,7 @@ class Options
      *
      * @var bool|null
      */
-    protected $scrollCollapse;
+    protected ?bool $scrollCollapse;
 
     /**
      * Set a throttle frequency for searching.
@@ -171,7 +171,7 @@ class Options
      *
      * @var int|null
      */
-    protected $searchDelay;
+    protected ?int $searchDelay;
 
     /**
      * Saved state validity duration.
@@ -180,7 +180,7 @@ class Options
      *
      * @var int|null
      */
-    protected $stateDuration;
+    protected ?int $stateDuration;
 
     /**
      * Set the zebra stripe class names for the rows in the table.
@@ -188,7 +188,12 @@ class Options
      *
      * @var array|null
      */
-    protected $stripeClasses;
+    protected ?array $stripeClasses;
+
+	protected ?bool $fixedHeader;
+
+	protected ?string $fixedColumns;
+	protected ?array $columnDefs;
 
     //-------------------------------------------------
     // Custom Options
@@ -200,7 +205,7 @@ class Options
      *
      * @var string
      */
-    protected $classes;
+    protected string $classes;
 
     /**
      * Enable or disable individual filtering.
@@ -208,7 +213,7 @@ class Options
      *
      * @var bool
      */
-    protected $individualFiltering;
+    protected bool $individualFiltering;
 
     /**
      * Position of individual search filter ('head', 'foot' or 'both').
@@ -216,7 +221,7 @@ class Options
      *
      * @var string
      */
-    protected $individualFilteringPosition;
+    protected string $individualFilteringPosition;
 
     /**
      * Determines whether to search in non-visible columns.
@@ -224,7 +229,7 @@ class Options
      *
      * @var bool
      */
-    protected $searchInNonVisibleColumns;
+    protected bool $searchInNonVisibleColumns;
 
     /**
      * The global search type.
@@ -232,7 +237,7 @@ class Options
      *
      * @var string
      */
-    protected $globalSearchType;
+    protected string $globalSearchType;
 
     public function __construct()
     {
@@ -246,8 +251,8 @@ class Options
     /**
      * @return $this
      */
-    public function configureOptions(OptionsResolver $resolver)
-    {
+    public function configureOptions(OptionsResolver $resolver): static
+	{
         $resolver->setDefaults([
             'defer_loading' => null,
             'display_start' => null,
@@ -267,6 +272,9 @@ class Options
             'search_delay' => null,
             'state_duration' => null,
             'stripe_classes' => null,
+            'fixed_header' => null,
+            'fixed_columns' => null,
+            'column_defs' => null,
             'classes' => Style::BASE_STYLE,
             'individual_filtering' => false,
             'individual_filtering_position' => 'head',
@@ -292,6 +300,9 @@ class Options
         $resolver->setAllowedTypes('search_delay', ['null', 'int']);
         $resolver->setAllowedTypes('state_duration', ['null', 'int']);
         $resolver->setAllowedTypes('stripe_classes', ['null', 'array']);
+        $resolver->setAllowedTypes('fixed_header', ['null', 'bool']);
+        $resolver->setAllowedTypes('fixed_columns', ['null', 'string']);
+        $resolver->setAllowedTypes('column_defs', ['null', 'array']);
         $resolver->setAllowedTypes('classes', 'string');
         $resolver->setAllowedTypes('individual_filtering', 'bool');
         $resolver->setAllowedTypes('individual_filtering_position', 'string');
@@ -311,8 +322,8 @@ class Options
     /**
      * @return array|int|null
      */
-    public function getDeferLoading()
-    {
+    public function getDeferLoading(): array|int|null
+	{
         if (\is_array($this->deferLoading)) {
             return $this->optionToJson($this->deferLoading);
         }
@@ -325,8 +336,8 @@ class Options
      *
      * @return $this
      */
-    public function setDeferLoading($deferLoading)
-    {
+    public function setDeferLoading(array|int|null $deferLoading): static
+	{
         $this->deferLoading = $deferLoading;
 
         return $this;
@@ -335,8 +346,8 @@ class Options
     /**
      * @return int|null
      */
-    public function getDisplayStart()
-    {
+    public function getDisplayStart(): ?int
+	{
         return $this->displayStart;
     }
 
@@ -345,8 +356,8 @@ class Options
      *
      * @return $this
      */
-    public function setDisplayStart($displayStart)
-    {
+    public function setDisplayStart(?int $displayStart): static
+	{
         $this->displayStart = $displayStart;
 
         return $this;
@@ -355,8 +366,8 @@ class Options
     /**
      * @return string|null
      */
-    public function getDom()
-    {
+    public function getDom(): ?string
+	{
         return $this->dom;
     }
 
@@ -365,8 +376,8 @@ class Options
      *
      * @return $this
      */
-    public function setDom($dom)
-    {
+    public function setDom(?string $dom): static
+	{
         $this->dom = $dom;
 
         return $this;
@@ -375,8 +386,8 @@ class Options
     /**
      * @return array|null
      */
-    public function getLengthMenu()
-    {
+    public function getLengthMenu(): mixed
+	{
         if (\is_array($this->lengthMenu)) {
             return $this->optionToJson($this->lengthMenu);
         }
@@ -389,8 +400,8 @@ class Options
      *
      * @return $this
      */
-    public function setLengthMenu($lengthMenu)
-    {
+    public function setLengthMenu(?array $lengthMenu): static
+	{
         $this->lengthMenu = $lengthMenu;
 
         return $this;
@@ -399,8 +410,8 @@ class Options
     /**
      * @return array|null
      */
-    public function getOrder()
-    {
+    public function getOrder(): mixed
+	{
         if (\is_array($this->order)) {
             return $this->optionToJson($this->order);
         }
@@ -413,8 +424,8 @@ class Options
      *
      * @return $this
      */
-    public function setOrder($order)
-    {
+    public function setOrder(?array $order): static
+	{
         $this->order = $order;
 
         return $this;
@@ -423,8 +434,8 @@ class Options
     /**
      * @return bool|null
      */
-    public function isOrderCellsTop()
-    {
+    public function isOrderCellsTop(): ?bool
+	{
         return $this->orderCellsTop;
     }
 
@@ -433,8 +444,8 @@ class Options
      *
      * @return $this
      */
-    public function setOrderCellsTop($orderCellsTop)
-    {
+    public function setOrderCellsTop(?bool $orderCellsTop): static
+	{
         $this->orderCellsTop = $orderCellsTop;
 
         return $this;
@@ -443,8 +454,8 @@ class Options
     /**
      * @return bool|null
      */
-    public function isOrderClasses()
-    {
+    public function isOrderClasses(): ?bool
+	{
         return $this->orderClasses;
     }
 
@@ -453,8 +464,8 @@ class Options
      *
      * @return $this
      */
-    public function setOrderClasses($orderClasses)
-    {
+    public function setOrderClasses(?bool $orderClasses): static
+	{
         $this->orderClasses = $orderClasses;
 
         return $this;
@@ -463,8 +474,8 @@ class Options
     /**
      * @return array|null
      */
-    public function getOrderFixed()
-    {
+    public function getOrderFixed(): ?array
+	{
         if (\is_array($this->orderFixed)) {
             return $this->optionToJson($this->orderFixed);
         }
@@ -477,8 +488,8 @@ class Options
      *
      * @return $this
      */
-    public function setOrderFixed($orderFixed)
-    {
+    public function setOrderFixed(?array $orderFixed): static
+	{
         $this->orderFixed = $orderFixed;
 
         return $this;
@@ -487,8 +498,8 @@ class Options
     /**
      * @return bool|null
      */
-    public function isOrderMulti()
-    {
+    public function isOrderMulti(): ?bool
+	{
         return $this->orderMulti;
     }
 
@@ -497,18 +508,74 @@ class Options
      *
      * @return $this
      */
-    public function setOrderMulti($orderMulti)
-    {
+    public function setOrderMulti(?bool $orderMulti): static
+	{
         $this->orderMulti = $orderMulti;
 
         return $this;
     }
 
+	/**
+	 * @return bool|null
+	 */
+	public function isFixedHeader(): ?bool
+	{
+		return $this->fixedHeader;
+	}
+
+	/**
+	 * @param bool|null $fixedHeader
+	 * @return $this
+	 */
+	public function setFixedHeader(?bool $fixedHeader): static
+	{
+		$this->fixedHeader = $fixedHeader;
+
+		return $this;
+	}
+
+	public function getFixedColumns(): ?string
+	{
+		return $this->fixedColumns;
+	}
+
+	/**
+	 * @param string|null $fixedColumns
+	 * @return $this
+	 */
+	public function setFixedColumns(?string $fixedColumns): static
+	{
+		$this->fixedColumns = $fixedColumns;
+
+		return $this;
+	}
+
+	/**
+	 * @return array|null
+	 * @throws \JsonException
+	 */
+	public function getColumnDefs(): ?string
+	{
+		if (\is_array($this->columnDefs)) {
+			return $this->optionToJson($this->columnDefs);
+		}
+
+		return $this->columnDefs;
+	}
+
+	/**
+	 * @param array|null $columnDefs
+	 */
+	public function setColumnDefs(?array $columnDefs): void
+	{
+		$this->columnDefs = $columnDefs;
+	}
+
     /**
      * @return int|null
      */
-    public function getPageLength()
-    {
+    public function getPageLength(): ?int
+	{
         return $this->pageLength;
     }
 
@@ -517,8 +584,8 @@ class Options
      *
      * @return $this
      */
-    public function setPageLength($pageLength)
-    {
+    public function setPageLength(?int $pageLength): static
+	{
         $this->pageLength = $pageLength;
 
         return $this;
@@ -527,8 +594,8 @@ class Options
     /**
      * @return string|null
      */
-    public function getPagingType()
-    {
+    public function getPagingType(): ?string
+	{
         return $this->pagingType;
     }
 
@@ -537,8 +604,8 @@ class Options
      *
      * @return $this
      */
-    public function setPagingType($pagingType)
-    {
+    public function setPagingType(?string $pagingType): static
+	{
         $this->pagingType = $pagingType;
 
         return $this;
@@ -547,8 +614,8 @@ class Options
     /**
      * @return string|null
      */
-    public function getRenderer()
-    {
+    public function getRenderer(): ?string
+	{
         return $this->renderer;
     }
 
@@ -557,8 +624,8 @@ class Options
      *
      * @return $this
      */
-    public function setRenderer($renderer)
-    {
+    public function setRenderer(?string $renderer): static
+	{
         $this->renderer = $renderer;
 
         return $this;
@@ -567,8 +634,8 @@ class Options
     /**
      * @return bool|null
      */
-    public function isRetrieve()
-    {
+    public function isRetrieve(): ?bool
+	{
         return $this->retrieve;
     }
 
@@ -577,8 +644,8 @@ class Options
      *
      * @return $this
      */
-    public function setRetrieve($retrieve)
-    {
+    public function setRetrieve(?bool $retrieve): static
+	{
         $this->retrieve = $retrieve;
 
         return $this;
@@ -587,8 +654,8 @@ class Options
     /**
      * @return string|null
      */
-    public function getRowId()
-    {
+    public function getRowId(): ?string
+	{
         return $this->rowId;
     }
 
@@ -597,8 +664,8 @@ class Options
      *
      * @return $this
      */
-    public function setRowId($rowId)
-    {
+    public function setRowId(?string $rowId): static
+	{
         $this->rowId = $rowId;
 
         return $this;
@@ -607,8 +674,8 @@ class Options
     /**
      * @return bool|null
      */
-    public function isScrollCollapse()
-    {
+    public function isScrollCollapse(): ?bool
+	{
         return $this->scrollCollapse;
     }
 
@@ -617,8 +684,8 @@ class Options
      *
      * @return $this
      */
-    public function setScrollCollapse($scrollCollapse)
-    {
+    public function setScrollCollapse(?bool $scrollCollapse): static
+	{
         $this->scrollCollapse = $scrollCollapse;
 
         return $this;
@@ -627,8 +694,8 @@ class Options
     /**
      * @return int|null
      */
-    public function getSearchDelay()
-    {
+    public function getSearchDelay(): ?int
+	{
         return $this->searchDelay;
     }
 
@@ -637,8 +704,8 @@ class Options
      *
      * @return $this
      */
-    public function setSearchDelay($searchDelay)
-    {
+    public function setSearchDelay(?int $searchDelay): static
+	{
         $this->searchDelay = $searchDelay;
 
         return $this;
@@ -647,8 +714,8 @@ class Options
     /**
      * @return int|null
      */
-    public function getStateDuration()
-    {
+    public function getStateDuration(): ?int
+	{
         return $this->stateDuration;
     }
 
@@ -657,8 +724,8 @@ class Options
      *
      * @return $this
      */
-    public function setStateDuration($stateDuration)
-    {
+    public function setStateDuration(?int $stateDuration): static
+	{
         $this->stateDuration = $stateDuration;
 
         return $this;
@@ -667,8 +734,8 @@ class Options
     /**
      * @return array|null
      */
-    public function getStripeClasses()
-    {
+    public function getStripeClasses(): ?array
+	{
         if (\is_array($this->stripeClasses)) {
             return $this->optionToJson($this->stripeClasses);
         }
@@ -681,8 +748,8 @@ class Options
      *
      * @return $this
      */
-    public function setStripeClasses($stripeClasses)
-    {
+    public function setStripeClasses(?array $stripeClasses): static
+	{
         $this->stripeClasses = $stripeClasses;
 
         return $this;
@@ -691,8 +758,8 @@ class Options
     /**
      * @return string
      */
-    public function getClasses()
-    {
+    public function getClasses(): string
+	{
         return $this->classes;
     }
 
@@ -701,8 +768,8 @@ class Options
      *
      * @return $this
      */
-    public function setClasses($classes)
-    {
+    public function setClasses(string $classes): static
+	{
         $this->classes = $classes;
 
         return $this;
@@ -711,8 +778,8 @@ class Options
     /**
      * @return bool
      */
-    public function isIndividualFiltering()
-    {
+    public function isIndividualFiltering(): bool
+	{
         return $this->individualFiltering;
     }
 
@@ -721,8 +788,8 @@ class Options
      *
      * @return $this
      */
-    public function setIndividualFiltering($individualFiltering)
-    {
+    public function setIndividualFiltering(bool $individualFiltering): static
+	{
         $this->individualFiltering = $individualFiltering;
 
         return $this;
@@ -731,8 +798,8 @@ class Options
     /**
      * @return string
      */
-    public function getIndividualFilteringPosition()
-    {
+    public function getIndividualFilteringPosition(): string
+	{
         return $this->individualFilteringPosition;
     }
 
@@ -741,8 +808,8 @@ class Options
      *
      * @return $this
      */
-    public function setIndividualFilteringPosition($individualFilteringPosition)
-    {
+    public function setIndividualFilteringPosition(string $individualFilteringPosition): static
+	{
         $this->individualFilteringPosition = $individualFilteringPosition;
 
         return $this;
@@ -751,8 +818,8 @@ class Options
     /**
      * @return bool
      */
-    public function isSearchInNonVisibleColumns()
-    {
+    public function isSearchInNonVisibleColumns(): bool
+	{
         return $this->searchInNonVisibleColumns;
     }
 
@@ -761,8 +828,8 @@ class Options
      *
      * @return $this
      */
-    public function setSearchInNonVisibleColumns($searchInNonVisibleColumns)
-    {
+    public function setSearchInNonVisibleColumns(bool $searchInNonVisibleColumns): static
+	{
         $this->searchInNonVisibleColumns = $searchInNonVisibleColumns;
 
         return $this;
@@ -771,8 +838,8 @@ class Options
     /**
      * @return string
      */
-    public function getGlobalSearchType()
-    {
+    public function getGlobalSearchType(): string
+	{
         return $this->globalSearchType;
     }
 
@@ -781,8 +848,8 @@ class Options
      *
      * @return $this
      */
-    public function setGlobalSearchType($globalSearchType)
-    {
+    public function setGlobalSearchType(string $globalSearchType): static
+	{
         $this->globalSearchType = $globalSearchType;
 
         return $this;
