@@ -289,7 +289,7 @@ class DatatableQueryBuilder
         $query = $qb->getQuery();
         $query->setHydrationMode(Query::HYDRATE_ARRAY)->useQueryCache($this->useQueryCache);
         //TODO Doctrine 3 error
-        \call_user_func_array([$query, 'useResultCache'], $this->useResultCacheArgs);
+        //\call_user_func_array([$query, 'useResultCache'], $this->useResultCacheArgs);
 
         return $query;
     }
@@ -308,7 +308,7 @@ class DatatableQueryBuilder
 
         $query = $qb->getQuery();
         $query->useQueryCache($this->useCountQueryCache);
-        \call_user_func_array([$query, 'useResultCache'], $this->useCountResultCacheArgs);
+        //\call_user_func_array([$query, 'useResultCache'], $this->useCountResultCacheArgs);
 
         return ! $qb->getDQLPart('groupBy')
             ? (int) $query->getSingleScalarResult()
@@ -553,8 +553,19 @@ class DatatableQueryBuilder
 
                         if($column->getName() === 'labels'){
 
-                            $qb->leftJoin('vdevice.labels', 'labels');
-                            $qb->andWhere('labels.labelId = ' . $searchValue);
+							$qb->leftJoin('vdevice.labels', 'labels');
+							if (str_contains($searchValue, '!')) {
+								//Index for negation is in format !number, so we can detect it and remove it
+								//than set orX
+								$searchValue = str_replace('!', '', $searchValue);
+								$andExpr = $qb->expr()->orX();
+								$qb->andWhere('labels.labelId != ' . $searchValue);
+							}else{
+								$qb->andWhere('labels.labelId = ' . $searchValue);
+							}
+
+                            //$qb->andWhere('labels.labelId = ' . $searchValue);
+
                         }
 
                         if($column->getName() === 'systemLabels'){
