@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace App\Controller\Admin\Ajax;
 
 use App\Entity\ConfigProfile\ConfigProfile;
+use App\Entity\Device\Device;
 use App\Form\ConfigProfile\ConfigProfileFileUploadType;
 use App\Form\ConfigProfile\ConfigProfileFromDeviceType;
 use App\Form\ConfigProfile\ConfigProfileFromExistingProfileType;
@@ -18,7 +19,7 @@ use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as Controller;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
 use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
 use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
@@ -55,6 +56,11 @@ class ConfigProfileController extends Controller
 			$requestData = $request->request->all()['config_profile_from_device'];
 			$deviceId = (int) ($requestData['device'] ?? null);
 
+			if(!$deviceId){
+				return new JsonResponse(['code' => 400, 'message' => 'error', 'errors' => ['error' => "Select the device please."]],
+					400);
+			}
+
             try {
 
 				$result = $configProfilesApi->createConfigProfileByDeviceId($deviceId);
@@ -121,6 +127,11 @@ class ConfigProfileController extends Controller
 
 			try {
 
+				if(!$profileId){
+					return new JsonResponse(['code' => 400, 'message' => 'error', 'errors' => ['error' => "Select the profile please."]],
+						400);
+				}
+
 				$result = $configProfilesApi->createConfigProfileByProfileId($profileId);
 
 				if($result->operation_result->Code === 0){
@@ -172,7 +183,7 @@ class ConfigProfileController extends Controller
 
 		if ($request->isXmlHttpRequest()) {
 
-			$form = $this->createForm(ConfigProfileFileUploadType::class);
+			$form = $this->createForm(ConfigProfileFileUploadType::class, null, ['label' => true]);
 			$form->handleRequest($request);
 
 			if ($form->isSubmitted() && $form->isValid()) {
@@ -285,6 +296,15 @@ class ConfigProfileController extends Controller
 
     }
 
+	/**
+	 * @param Request $request
+	 * @param ConfigProfiles $configProfilesApi
+	 * @return Response
+	 * @throws ClientExceptionInterface
+	 * @throws RedirectionExceptionInterface
+	 * @throws ServerExceptionInterface
+	 * @throws TransportExceptionInterface
+	 */
 	#[Route(path: '/add-devices', name: 'devices_add', methods: ['POST'])]
 	public function addDevicesToConfigurationProfileAction(Request $request, ConfigProfiles $configProfilesApi): Response {
 
@@ -308,13 +328,10 @@ class ConfigProfileController extends Controller
 			try{
 				$configProfilesApi->assignDeviceToConfigProfile($configProfileId, $deviceIds);
 			}catch (\Exception $exception){
-				die($exception->getMessage());
+				return new JsonResponse(['status' => 'Error', 'errors' => $exception->getMessage()], 200);
 			}
 
-			//return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
-			//	400);
-
-			return new JsonResponse(['code' => 200, 'message' => 'Devices sucessfully inserted to the group.', 'errors' => ['errors' => ['']]],
+			return new JsonResponse(['code' => 200, 'message' => 'Devices successfully inserted to the group.', 'errors' => ['errors' => ['']]],
 				200);
 
 		}
@@ -324,8 +341,26 @@ class ConfigProfileController extends Controller
 
 	}
 
+	/**
+	 * @param int $configProfileId
+	 * @param int $deviceId
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @param ConfigProfiles $configProfilesApi
+	 * @return Response
+	 * @throws ClientExceptionInterface
+	 * @throws RedirectionExceptionInterface
+	 * @throws ServerExceptionInterface
+	 * @throws TransportExceptionInterface
+	 */
 	#[Route(path: '/remove-device/{configProfileId}/{deviceId}', name: 'device_remove', methods: ['GET'])]
-	public function deviceConfigurationProfileRemoveAction(Request $request, int $configProfileId, int $deviceId, ManagerRegistry $managerRegistry): Response {
+	public function deviceConfigurationProfileRemoveAction(
+		int $configProfileId,
+		int $deviceId,
+		Request $request,
+		ManagerRegistry $managerRegistry,
+		ConfigProfiles $configProfilesApi
+	): Response {
 
 		if (!$request->isXmlHttpRequest()) {
 			return new Response('Bad Request', 400);
@@ -333,29 +368,27 @@ class ConfigProfileController extends Controller
 
 		if(isset($request->request)) {
 
-			if (!isset($configProfileId) && !isset($deviceId))
-				return new JsonResponse(['status' => 'Error'],400);
-
-			die('tu');
-
-			$monitoringGroup = $managerRegistry->getRepository(MonitoringGroup::class)->findOneBy(['id' => $monitoringGroupId]);
-			$device = $managerRegistry->getRepository(Device::class)->findOneBy(['id' => $deviceId]);
-			$monitoringGroupMapping = $managerRegistry->getRepository(MonitoringGroupMapping::class)->findOneBy(
-				['device' => $device, 'monitoringGroup' => $monitoringGroup]);
-
-			if ($monitoringGroupMapping) {
-
-				$em = $managerRegistry->getManager();
-				$em->remove($monitoringGroupMapping);
-				$em->flush();
-
+			if (!isset($configProfileId) && !isset($deviceId)) {
+				return new JsonResponse(['status' => 'Error'], 400);
 			}
 
-			return new JsonResponse([
-				'code' => 200,
-				'message' => 'Device from the Monitoring Group was removed.',
-				'errors' => [],
-				200]);
+			$configProfile = $managerRegistry->getRepository(ConfigProfile::class)->findOneBy(['id' => $configProfileId]);
+			$device = $managerRegistry->getRepository(Device::class)->findOneBy(['id' => $deviceId]);
+
+			if ($configProfile && $device) {
+
+				try{
+
+					$configProfilesApi->unassignDeviceFromConfigProfile([$device->getId()]);
+
+				}catch (\Exception $exception){
+					return new JsonResponse(['status' => 'Error', 'errors' => $exception->getMessage()], 200);
+				}
+
+				return new JsonResponse(['code' => 200, 'message' => 'Devices successfully unassigned from the Config profile.', 'errors' => ['errors' => ['']]],
+					200);
+
+			}
 
 		}
 
@@ -365,6 +398,10 @@ class ConfigProfileController extends Controller
 
 	}
 
+	/**
+	 * @param array $profileData
+	 * @return array
+	 */
 	private function makeConfigProfileDataToSend(array $profileData): array
 	{
 
