@@ -17,13 +17,15 @@ use Doctrine\DBAL\ArrayParameterType;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\ParameterType;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\Persistence\ManagerRegistry;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as Controller;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 use App\Service\Api\Device as DeviceApi;
+use Symfony\Component\Security\Core\Exception\AccessDeniedException;
 use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
 use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
 use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
@@ -673,6 +675,43 @@ class DeviceController extends Controller
 
     }
 
+	#[Route(path: '/update/device-note', name: 'update_device_note', methods: ['PUT'])]
+	public function updateDeviceNoteAction(Request $request, ManagerRegistry $managerRegistry, EntityManagerInterface $entityManager): Response
+	{
+
+		if ($request->isXmlHttpRequest()) {
+
+			$deviceId = (int) $request->request->get('pk');
+			$noteId = (int) $request->request->get('note');
+			$value = $request->request->get('value');
+			$token = $request->request->get('token');
+
+			// check token
+			if (! $this->isCsrfTokenValid('device-detail-notes', $token)) {
+				throw new AccessDeniedException('DeviceNote::updateAction(): The CSRF token is invalid.');
+			}
+
+			$device = $managerRegistry->getRepository(Device::class)->find($deviceId);
+
+			if(!$device){
+				return new JsonResponse(['message' => 'Something bad happened.'],
+					400);
+			}
+
+			$device->noteDevice->{'setNote' . $noteId}($value);
+
+			$entityManager->persist($device);
+			$entityManager->flush();
+
+			return new JsonResponse(['status' => 'Success', 'message' => 'Updated.'],
+				200);
+		}
+
+		return new JsonResponse(['status' => 'Error', 'message' => 'Something bad happened.'],
+			400);
+
+	}
+
     /**
      * @param Request $request
      * @param ManagerRegistry $managerRegistry
