@@ -10,16 +10,17 @@ use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as Controller;
 use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 #[Route(path: '/admin/ajax/settings', name: 'ajax_settings_')]
 class SettingsController extends Controller
 {
 
-    /**
-     * Set device table columns
-     * @return Response
-     */
+	/**
+	 * @param Request $request
+	 * @param ConfigurationService $configurationService
+	 * @return Response
+	 */
     #[Route(path: '/device-table-columns', name: 'device_table_columns', methods: ['POST'])]
     public function createLabelAction(Request $request, ConfigurationService $configurationService): Response {
 
@@ -29,29 +30,39 @@ class SettingsController extends Controller
 
         }
 
+		$toSave = [];
+
         if (isset($request->request)) {
 
-            $columns = (array)$request->get('columns');
-            //$availableColumns = DeviceDatatable::availableColumns;
+            $columns = (array) $request->request->getIterator('columns');
+			if(array_key_exists('columns', $columns)){
 
-            $toSave = [];
+				$columns = $columns['columns'];
+				$availableColumns = array_keys(DeviceDatatable::availableColumns);
 
-            foreach ($columns as $column){
+				foreach ($columns as $column){
 
-                //$toSave[] = $availableColumns[$column];
-                $toSave[] = $column;
+					if(in_array($column, $availableColumns, false)){
+						$toSave[] = $column;
+					}
 
-            }
+				}
+
+			}
 
             if(empty($toSave)){
                 $toSave = DeviceDatatable::showColumns;
-            }
+				$message = 'Device Table Columns settings was set <b>to the default.</b>';
+            }else{
+				$message = 'Device Table Columns settings was updated.';
+			}
 
             $configurationService->setDeviceTableColumns($toSave);
 
                 return new JsonResponse([
                     'code' => 200,
-                    'message' => 'success',
+					'success' => true,
+                    'message' => $message,
                 ],200);
 
 
@@ -59,6 +70,7 @@ class SettingsController extends Controller
 
         return new JsonResponse([
             'code' => 400,
+			'success' => false,
             'message' => 'error',
             ],400);
     }
