@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
@@ -23,7 +25,7 @@ use Symfony\Component\HttpFoundation\JsonResponse;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 class AlertController extends BaseController
 {
@@ -310,9 +312,13 @@ class AlertController extends BaseController
 
         $formData->setTargetType($targetType);
         $formData->setTargetSpec($targetSpec);
-        if($targetAmount) $formData->setTargetAmount($targetAmount);
+        if($targetAmount) {
+			$formData->setTargetAmount((int) $targetAmount);
+		}
         $formData->setOperFirst($targetOperFirst);
-        if($targetOperSecond) $formData->setOperSecond($targetOperSecond);
+        if($targetOperSecond) {
+			$formData->setOperSecond($targetOperSecond);
+		}
         $formData->setNumFirst((float) $targetNumFirst);
         if(!is_null($targetNumSecond)){
 
