@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\Datatable;
 
 use App\Entity\Device\Device;
@@ -10,6 +12,8 @@ use App\Entity\MonitoringGroup\MonitoringGroup;
 use DateTime;
 use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\ORM\EntityManagerInterface;
+use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\Persistence\ManagerRegistry;
 use Exception;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
@@ -17,31 +21,33 @@ use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\PropertyAccess\PropertyAccess;
 use Symfony\Component\PropertyAccess\PropertyAccessor;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 use Symfony\Component\Security\Core\Exception\AccessDeniedException;
 
 class DatatableController extends AbstractController
 {
 
-    public function __construct(private readonly ManagerRegistry $managerRegistry)
+    public function __construct(private readonly ManagerRegistry $managerRegistry,
+								private readonly EntityManagerInterface $entityManager
+	)
     {
     }
 
-    /**
-     * Edit field.
-     *
-     *
-     * @throws Exception
-     *
-     * @return Response
-     */
+	/**
+	 * Edit field.
+	 *
+	 *
+	 * @param Request $request
+	 * @return Response
+	 * @throws Exception
+	 */
     #[Route(path: '/datatables/edit/field', name: 'app_datatables_edit', methods: ['POST'])]
     public function editAction(Request $request): Response
     {
 
         if ($request->isXmlHttpRequest()) {
             // x-editable sends some default parameters
-            $pk = $request->request->get('pk');       // entity primary key
+            $pk = (int) $request->request->get('pk');       // entity primary key
             $field = $request->request->get('name');  // e.g. comments.createdBy.username
             $value = $request->request->get('value'); // the new value
 
@@ -61,11 +67,17 @@ class DatatableController extends AbstractController
                 $entityClassName = Device::class;
             }
 
-            // get an object by its primary key
-            $entity = $this->getEntityByPk($entityClassName, $pk);
+			//Check if it is editable through entity annotations options: ['editable' => true]
+			$isAllowed = $this->checkEntityMetadataRights($entityClassName, $field);
 
-            /** @var PropertyAccessor $accessor */
-            /** @noinspection PhpUndefinedMethodInspection */
+			if(!$isAllowed){
+				return new Response('Not allowed.', 405);
+			}
+
+			// get an object by its primary key
+			$entity = $this->getEntityByPk($entityClassName, $pk);
+
+			/** @var PropertyAccessor $accessor */
             $accessor = PropertyAccess::createPropertyAccessorBuilder()
                 ->enableMagicCall()
                 ->getPropertyAccessor()
@@ -133,12 +145,12 @@ class DatatableController extends AbstractController
         return $entity;
     }
 
-    /**
-     * @param string $originalTypeOfField
-     * @param mixed $value
-     * @return bool|DateTime|float|int|mixed|string|null
-     * @throws \DateMalformedStringException
-     */
+	/**
+	 * @param string $originalTypeOfField
+	 * @param mixed $value
+	 * @return mixed
+	 * @throws Exception
+	 */
     private function normalizeValue(string $originalTypeOfField, mixed $value): mixed
     {
         switch ($originalTypeOfField) {
@@ -168,15 +180,16 @@ class DatatableController extends AbstractController
 
                 break;
             default:
-                throw new Exception("DatatableController::prepareValue(): The field type {$originalTypeOfField} is not editable.");
+                throw new \RuntimeException("DatatableController::prepareValue(): The field type {$originalTypeOfField} is not editable.");
         }
 
         return $value;
     }
 
-    /**
-     * @throws Exception
-     */
+	/**
+	 * @param string $str
+	 * @return bool|null
+	 */
     private function strToBool(string $str): ?bool
     {
         $str = strtolower($str);
@@ -193,6 +206,34 @@ class DatatableController extends AbstractController
             return false;
         }
 
-        throw new Exception('DatatableController::strToBool(): Cannot convert string to boolean, expected string "true" or "false".');
+        throw new \RuntimeException('DatatableController::strToBool(): Cannot convert string to boolean, expected string "true" or "false".');
     }
+
+	/**
+	 * @param string $entityClassName
+	 * @param string $field
+	 * @return bool
+	 * @throws MappingException
+	 */
+	private function checkEntityMetadataRights(string $entityClassName, string $field): bool
+	{
+
+		// Get all metadata for the entity
+		$metadata = $this->entityManager->getClassMetadata($entityClassName);
+
+		// Doctrine stores the ReflectionProperty for every mapped field
+		if ($metadata->getPropertyAccessor($field)) {
+
+			$mapping = $metadata->getFieldMapping($field);
+			// Access the options array
+			$isEditable = $mapping['options']['datatable_editable'] ?? false;
+
+			if($isEditable){
+				return true;
+			}
+		}
+
+		return false;
+
+	}
 }
