@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\Device;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableQueryBuilder;
@@ -9,6 +11,7 @@ use App\Entity\AgentProfile\AgentProfile;
 use App\Entity\Alert\Alert;
 use App\Entity\ConfigProfile\ConfigProfile;
 use App\Entity\Device\Device;
+use App\Entity\Device\DeviceOsType;
 use App\Entity\Snmp\Device as SnmpDevice;
 use App\Entity\Device\DeviceOsVersion;
 use App\Entity\Device\DeviceType;
@@ -24,10 +27,9 @@ use App\Exception\DeviceNotFoundException;
 use App\Exception\DeviceNumberInvalidException;
 use App\Exception\MonitoringGroupNotFoundException;
 use App\Form\DeleteType;
-use App\Form\Device\ConfigProfileCloneDeviceToType;
-use App\Form\Device\ConfigProfileCloneFromDeviceType;
 use App\Form\Device\DeviceAgentProfileType;
 use App\Form\Device\DeviceAuthProfileType;
+use App\Form\Device\DeviceConfigProfileType;
 use App\Form\Device\DeviceCustomLabelType;
 use App\Form\Device\DeviceCustomModuleDownloadType;
 use App\Form\Device\DeviceHostnameType;
@@ -35,13 +37,13 @@ use App\Form\Device\DeviceNetDevicesType;
 use App\Form\Device\DeviceSystemLabelType;
 use App\Form\Device\FwVersionType;
 use App\Form\Device\MonitoringGroupType;
-use App\Repository\ConfigProfileRepository;
 use App\Repository\DeviceRepository;
 use App\Repository\DeviceUserModuleRepository;
 use App\Repository\MonitoringGroupRepository;
 use App\Repository\ProductFlagsRepository;
 use App\Service\Api\AgentProfiles;
 use App\Service\Api\ApiService;
+use App\Service\Api\ConfigProfiles;
 use App\Service\Api\DashboardLights;
 use App\Service\Command;
 use App\Service\DatatableService;
@@ -50,6 +52,7 @@ use App\Service\History;
 use Doctrine\DBAL\Exception;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\Persistence\ManagerRegistry;
+use Psr\Log\LoggerInterface;
 use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
 use Symfony\Component\Form\FormInterface;
 use Symfony\Component\HttpFoundation\BinaryFileResponse;
@@ -58,7 +61,7 @@ use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpFoundation\ResponseHeaderBag;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 use Symfony\Component\Serializer\Encoder\CsvEncoder;
 use Symfony\Component\Serializer\Normalizer\ObjectNormalizer;
 use Symfony\Component\Serializer\Serializer;
@@ -69,16 +72,17 @@ class DeviceController extends BaseController
 
     private ?Response $render = null;
 
-    /**
-     * @param ManagerRegistry $managerRegistry
-     * @param EntityManagerInterface $entityManager
-     * @param DeviceRepository $deviceRepository
-     * @param ProductFlagsRepository $productFlagsRepository
-     */
-    public function __construct(ManagerRegistry  $managerRegistry,
-                                private readonly EntityManagerInterface $entityManager,
-                                private readonly DeviceRepository $deviceRepository,
-                                private readonly ProductFlagsRepository $productFlagsRepository) {
+	/**
+	 * @param ManagerRegistry $managerRegistry
+	 * @param EntityManagerInterface $entityManager
+	 * @param DeviceRepository $deviceRepository
+	 * @param ProductFlagsRepository $productFlagsRepository
+	 * @param LoggerInterface $logger
+	 */
+    public function __construct(ManagerRegistry                         $managerRegistry,
+								private readonly EntityManagerInterface $entityManager,
+								private readonly DeviceRepository       $deviceRepository,
+								private readonly ProductFlagsRepository $productFlagsRepository, private readonly LoggerInterface $logger) {
 
         parent::__construct($managerRegistry);
 
@@ -96,7 +100,7 @@ class DeviceController extends BaseController
     {
 
         $isAjax = $request->isXmlHttpRequest();
-        $this->filter = $request->get('column');
+        $this->filter = $request->query->get('column');
 
         $datatable = $datatableService->getDeviceDatatable();
 
@@ -176,21 +180,25 @@ class DeviceController extends BaseController
             'alertId' => $alert->getId(),
         ]);
 
-        return $this->render('device/index.html.twig', ['datatable' => $datatable, 'filter' => $this->filter, 'title' => 'List of devices for trigerred alert: <a href="' . $alertUrl . '">' . $alert->getName() . '</a>']);
+        return $this->render('device/index.html.twig', [
+			'datatable' => $datatable,
+			'filter' => $this->filter,
+			'title' => 'List of devices for trigerred alert: <a href="' . $alertUrl . '">' . $alert->getName() . '</a>'
+		]);
 
     }
 
-    /**
-     * @param int $monitoringGroupId
-     * @param int $subsetId
-     * @param Request $request
-     * @param ManagerRegistry $managerRegistry
-     * @param DashboardLights $dashboardLightsApi
-     * @param DatatableResponse $responseService
-     * @param DatatableService $datatableService
-     * @return JsonResponse|Response
-     * @throws MonitoringGroupNotFoundException
-     */
+	/**
+	 * @param int $monitoringGroupId
+	 * @param int $subsetId
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @param DashboardLights $dashboardLightsApi
+	 * @param DatatableResponse $responseService
+	 * @param DatatableService $datatableService
+	 * @return JsonResponse|Response
+	 * @throws MonitoringGroupNotFoundException
+	 */
     #[Route(path: '/dashboard/monitoring-group/{monitoringGroupId}/subset/{subsetId}', name: '_dashboard_light')]
     public function listDevicesByDashboardLight(int $monitoringGroupId, int $subsetId, Request $request,
                                                 ManagerRegistry $managerRegistry, DashboardLights $dashboardLightsApi,
@@ -219,7 +227,6 @@ class DeviceController extends BaseController
             $datatableQueryBuilder = new DatatableQueryBuilder($requestParams, $datatable);
             $responseService->setDatatableQueryBuilder($datatableQueryBuilder);
 
-            /** @var QueryBuilder $qb */
             $qb = $datatableQueryBuilder->getQb();
             $qb->andWhere('vdevice.id IN (:deviceIds)');
             $qb->andWhere('vdevice.deleted = :deleted');
@@ -291,7 +298,6 @@ class DeviceController extends BaseController
             $datatableQueryBuilder = new DatatableQueryBuilder($requestParams, $datatable);
             $responseService->setDatatableQueryBuilder($datatableQueryBuilder);
 
-            /** @var QueryBuilder $qb */
             $qb = $datatableQueryBuilder->getQb();
             $qb->andWhere('vdevice.id IN (:deviceIds)');
             $qb->andWhere('vdevice.deleted = :deleted');
@@ -305,7 +311,11 @@ class DeviceController extends BaseController
             'alertId' => $alert->getId(),
         ]);
 
-        $this->render = $this->render('device/index.html.twig', ['datatable' => $datatable, 'filter' => $this->filter, 'title' => 'List of devices for past alert: <a href="' . $alertUrl . '">' . $alert->getName() . '</a>']);
+        $this->render = $this->render('device/index.html.twig', [
+			'datatable' => $datatable,
+			'filter' => $this->filter,
+			'title' => 'List of devices for past alert: <a href="' . $alertUrl . '">' . $alert->getName() . '</a>'
+		]);
         return $this->render;
 
     }
@@ -341,31 +351,28 @@ class DeviceController extends BaseController
 
     }
 
-    /**
-     * @param int $deviceId
-     * @param ManagerRegistry $managerRegistry
-     * @param DeviceRepository $deviceRepository
-     * @param ConfigProfileRepository $configProfileRepository
-     * @param History $historyService
-     * @param Command $commandService
-     * @param ParameterBagInterface $params
-     * @param ApiService $apiService
-     * @param Request $request
-     * @param DeviceUserModuleRepository $userModuleRepository
-     * @param MonitoringGroupRepository $monitoringGroupRepository
-     * @param AgentProfiles $agentProfilesApi
-     * @return BinaryFileResponse|RedirectResponse|Response
-     * @throws DeviceNotFoundException
-     * @throws DeviceNumberInvalidException
-     * @throws Exception
-     * @throws \JsonException
-     */
+	/**
+	 * @param int $deviceId
+	 * @param ManagerRegistry $managerRegistry
+	 * @param History $historyService
+	 * @param Command $commandService
+	 * @param ParameterBagInterface $params
+	 * @param ApiService $apiService
+	 * @param Request $request
+	 * @param DeviceUserModuleRepository $userModuleRepository
+	 * @param MonitoringGroupRepository $monitoringGroupRepository
+	 * @param AgentProfiles $agentProfilesApi
+	 * @param ConfigProfiles $configProfilesApi
+	 * @return BinaryFileResponse|RedirectResponse|Response
+	 * @throws DeviceNotFoundException
+	 * @throws DeviceNumberInvalidException
+	 * @throws Exception
+	 * @throws \JsonException
+	 */
     #[Route(path: '/{deviceId}', name: '_detail')]
     public function deviceDetail(
         int $deviceId,
         ManagerRegistry $managerRegistry,
-        DeviceRepository $deviceRepository,
-        ConfigProfileRepository $configProfileRepository,
         History $historyService,
         Command $commandService,
         ParameterBagInterface $params,
@@ -373,8 +380,10 @@ class DeviceController extends BaseController
         Request $request,
         DeviceUserModuleRepository $userModuleRepository,
         MonitoringGroupRepository $monitoringGroupRepository,
-        AgentProfiles $agentProfilesApi)
-    {
+        AgentProfiles $agentProfilesApi,
+		ConfigProfiles $configProfilesApi
+		): BinaryFileResponse|RedirectResponse|Response
+	{
 
         if (!is_numeric($deviceId)) {
 
@@ -382,7 +391,7 @@ class DeviceController extends BaseController
 
         }
 
-        /** @var \App\Entity\Device\Device $device */
+        /** @var Device $device */
         $device = $managerRegistry->getRepository(Device::class)->findOneBy(['id' => $deviceId]);
 
         if (!$device || $device->isDeleted()) {
@@ -391,53 +400,21 @@ class DeviceController extends BaseController
 
         }
 
-        $findBy = ['available' => 1, 'approved' => 1];
+		$deviceType = $device->getDevType();
+		$osType = $managerRegistry->getRepository(DeviceOsType::class)->findOneBy(['devType' => $deviceType]);
+		$osVersions = $managerRegistry->getRepository(DeviceOsVersion::class)->findBy(['osType' => $osType, 'available' => 1, 'approved' => 1], ['version' => 'DESC']);
 
-        if (!is_null($device->getOsVer())) {
-
-            $findBy['osType'] = $device->getOsVer()->getOsType();
-
-        }
-
-        $osVersions = $managerRegistry->getRepository(DeviceOsVersion::class)->findBy($findBy, ['version' => 'DESC']);
-
-
-        $clonedFromDeviceId = (!empty($device->getConfigProfileAutomatic()->getAutomatic())) ? $device->getConfigProfileAutomatic()->getAutomatic()->getId() : null;
-        $devicesToCloneToExcludeDeviceIds = [$device->getId()];
-        if (isset($clonedFromDeviceId)) {
-            $devicesToCloneToExcludeDeviceIds[] = $clonedFromDeviceId;
-        }
-
-        $devicesTocloneTo = $deviceRepository->getDevicesExcept($devicesToCloneToExcludeDeviceIds, $device->getDevType()->getId());
-
-        $deviceToClonedToResult = $configProfileRepository->findOneBy(['automatic' => $device]);
-        $devicesToClonedTo = [];
-        if ($deviceToClonedToResult) {
-            $devicesToClonedTo = $deviceRepository->findBy(['configProfile' => $deviceToClonedToResult]);
-
-            foreach ($devicesToClonedTo as $deviceToClonedTo) {
-
-                $devicesToClonedToIds[] = $deviceToClonedTo->getId();
-
-            }
-        }
-
-        $devicesToCloneFromExcludeDeviceIds[] = $device->getId();
-        if (isset($devicesToClonedToIds)) {
-            $devicesToCloneFromExcludeDeviceIds = array_merge($devicesToCloneFromExcludeDeviceIds, $devicesToClonedToIds);
-        }
-
-        $devicesToCloneFrom = $configProfileRepository->getDevicesToBeClonedFromPlainSql($devicesToCloneFromExcludeDeviceIds, $device->getDevType()->getId());
+		$configProfiles = $this->managerRegistry->getRepository(ConfigProfile::class)->findBy(['directive' => 1, 'deleted' => 0]);
 
         $fwVersionForm = $this->createForm(FwVersionType::class, ['osVersions' => $osVersions, 'showNoSpecific' => !is_null($device->getOsVerDesired()), 'device' => $device]);
         $deleteForm = $this->createForm(DeleteType::class, ['text' => 'Delete device']);
-        $configProfileCloneFromForm = $this->createForm(ConfigProfileCloneFromDeviceType::class, ['device' => $device, 'devicesToCloneFrom' => $devicesToCloneFrom, 'isCloned' => !is_null($device->configProfile)]);
-        $configProfileCloneToForm = $this->createForm(ConfigProfileCloneDeviceToType::class, ['devicesToClonedTo' => $devicesToClonedTo, 'devicesToCloneTo' => $devicesTocloneTo, 'isCloned' => (count($devicesToClonedTo) > 0)]);
-        $hostnameForm = $this->createForm(DeviceHostnameType::class, ['device' => $device]);
+		$configProfileForm = $this->createForm(DeviceConfigProfileType::class, [
+			'device' => $device, 'configProfiles' => $configProfiles, 'isAssigned' => ( ($device->getConfigProfile()) ? true : false )]);
+		$hostnameForm = $this->createForm(DeviceHostnameType::class, ['device' => $device]);
         $customModuleDownloadForm = $this->createForm(DeviceCustomModuleDownloadType::class, ['device' => $device]);
         $netDevicesForm = $this->createForm(DeviceNetDevicesType::class, ['netDevices' => $device->getNetDevices()]);
 
-        list($labelsForm, $systemLabelsForm) = $this->getLabelForms($managerRegistry, $device, $request);
+        [$labelsForm, $systemLabelsForm] = $this->getLabelForms($managerRegistry, $device, $request);
 
         $monitoringGroups = $monitoringGroupRepository->getAllMonitoringGroups();
         $deviceMonitoringGroups = $device->monitoringGroupMappings;
@@ -453,11 +430,9 @@ class DeviceController extends BaseController
 
         $fwVersionForm->handleRequest($request);
         $deleteForm->handleRequest($request);
-        $configProfileCloneFromForm->handleRequest($request);
-        $configProfileCloneToForm->handleRequest($request);
         $hostnameForm->handleRequest($request);
-
         $monitoringGroupsForm->handleRequest($request);
+		$configProfileForm->handleRequest($request);
         $agentProfilesForm->handleRequest($request);
         $authProfilesForm->handleRequest($request);
         $customModuleDownloadForm->handleRequest($request);
@@ -467,108 +442,17 @@ class DeviceController extends BaseController
         $historyTimeLegend = '"' . implode('","', $historyService->getHistoryTimeLegend($historyTypeId)) . '"';
         $historyData = $historyService->getHistoryDataForDevice($historyTypeId, $device->getId());
 
-        /*var_dump($historyData);
-        die();*/
-
         if ($deleteForm->isSubmitted() && $deleteForm->isValid()) {
-
-            $snmpDevice = $managerRegistry->getRepository(SnmpDevice::class);
-            if ($apiService->deleteDevice($device->getId()) !== false) {
-
-                try{
-                    $snmpDevice->removeSnmpDevice($device->getId());
-                    $this->addFlash(
-                        'success',
-                        'Device was successfully deleted.'
-                    );
-                }catch (\Exception $e){
-                    $this->addFlash(
-                        'danger',
-                        'Device was not deleted.'
-                    );
-                }
-
-            } else {
-
-                $this->addFlash(
-                    'danger',
-                    'Device was not deleted.'
-                );
-
-            }
-
-            return $this->redirectToRoute('admin_devices');
-
-        }
+			return $this->processDeleteFormSubmit($managerRegistry, $apiService, $device);
+		}
 
         if ($customModuleDownloadForm->isSubmitted() && $customModuleDownloadForm->isValid()) {
-
-            $formData = $customModuleDownloadForm->getData();
-
-            $devId = $formData['deviceId'];
-            $deviceTypeId = $formData['deviceType'];
-
-            $exitCode = $commandService->runCustomizedAgentGenerator($devId);
-
-            if ($exitCode === 0) {
-
-                $deviceType = $managerRegistry->getRepository(DeviceType::class)->findOneBy(['id' => $deviceTypeId]);
-
-                $mapping = $deviceType->getDeviceTypeAgentMapping();
-                if (count($mapping) > 1) {
-
-                    $this->addFlash(
-                        'danger',
-                        'No valid agent data given.'
-                    );
-
-                } else {
-
-                    $customizedAgentPath = $params->get('app.customizedAgentPath');
-                    $agent = $mapping[0]->getDeviceAgent();
-
-                    $file = $customizedAgentPath . $devId . DIRECTORY_SEPARATOR . $agent->getDirName() . DIRECTORY_SEPARATOR . $agent->getPackageName();
-
-                    $response = new BinaryFileResponse($file);
-                    $response->setContentDisposition(
-                        ResponseHeaderBag::DISPOSITION_ATTACHMENT,
-                        $agent->getPackageName()
-                    );
-
-                    return $response;
-                }
-
-            } else {
-
-                $this->addFlash(
-                    'danger',
-                    'The agent cannot be created.'
-                );
-
-            }
-
-            return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-        }
+			return $this->processCustomModuleDownloadFormSubmit($customModuleDownloadForm, $commandService, $managerRegistry, $params, $device);
+		}
 
         if ($hostnameForm->isSubmitted() && $hostnameForm->isValid()) {
-
-            // $form->getData() holds the submitted values
-            // but, the original `$task` variable has also been updated
-            $formData = $hostnameForm->getData();
-
-            $device->setHostnameDesired($formData['hostname']);
-            $managerRegistry->getManager()->persist($device);
-            $managerRegistry->getManager()->flush();
-
-            $this->addFlash(
-                'success',
-                'Hostname will be updated.'
-            );
-
-            return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-        }
+			return $this->processHostnameFormSubmit($hostnameForm, $device, $managerRegistry);
+		}
 
         if ($labelsForm->isSubmitted() && $labelsForm->isValid()) {
             return $this->processCustomLabelsFormSubmit($labelsForm, $managerRegistry, $device);
@@ -588,243 +472,26 @@ class DeviceController extends BaseController
 
         if ($fwVersionForm->isSubmitted() && $fwVersionForm->isValid()){
             return $this->processFwVersionFormSubmit($fwVersionForm, $device, $managerRegistry);
-
         }
 
+		if ($configProfileForm->isSubmitted() && $configProfileForm->isValid()){
+			return $this->processConfigProfileFormSubmit($configProfileForm, $device, $managerRegistry, $configProfilesApi);
+		}
+
         if ($agentProfilesForm->isSubmitted() && $agentProfilesForm->isValid()){
-
-            $formData = $agentProfilesForm->getData();
-            $agentProfileId = $formData['agent_profile'];
-
-            $agentProfile = $managerRegistry->getRepository(AgentProfile::class)
-                ->findOneBy(['id' =>  $agentProfileId]);
-
-            $result = $agentProfilesApi->assignDeviceAgentProfile($agentProfileId, [$deviceId]);
-
-            /*$device->setAgentProfile($agentProfile);
-            $managerRegistry->getManager()->persist($device);
-            $managerRegistry->getManager()->flush();*/
-
-            $this->addFlash(
-                'success',
-                'Agent profile was updated.'
-            );
-
-            return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-        }
+			return $this->processAgentProfileFormSubmit($agentProfilesForm, $managerRegistry, $agentProfilesApi, $device);
+		}
 
         if ($authProfilesForm->isSubmitted() && $authProfilesForm->isValid()){
-
-            $formData = $authProfilesForm->getData();
-            $authProfileId = $formData['auth_profile'];
-
-            $authProfile = $managerRegistry->getRepository(AuthProfile::class)
-                ->findOneBy(['id' =>  $authProfileId]);
-
-            $device->setAuthProfile($authProfile);
-            $managerRegistry->getManager()->persist($device);
-            $managerRegistry->getManager()->flush();
-
-            $this->addFlash(
-                'success',
-                'Auth profile was updated.'
-            );
-
-            return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-        }
-
-        if ($configProfileCloneFromForm->isSubmitted() && $configProfileCloneFromForm->isValid()) {
-
-            $formData = $configProfileCloneFromForm->getData();
-
-            if($configProfileCloneFromForm->offsetExists('no_clone') && $configProfileCloneFromForm->get('no_clone')->isClicked()){
-
-                $device->setConfigProfile(null);
-                $managerRegistry->getManager()->persist($device);
-                $managerRegistry->getManager()->flush();
-
-                $this->addFlash(
-                    'success',
-                    'Device cloning was removed.'
-                );
-
-
-            }else{
-
-                $configProfileId = $formData['config_profile'];
-
-                $configProfile = $managerRegistry->getRepository(ConfigProfile::class)
-                    ->findOneBy(['id' =>  $configProfileId]);
-
-                $device->setConfigProfile($configProfile);
-                $managerRegistry->getManager()->persist($device);
-                $managerRegistry->getManager()->flush();
-
-                $this->addFlash(
-                    'success',
-                    'Device config will be cloned.'
-                );
-
-            }
-
-            return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-        }
-
-        if ($configProfileCloneToForm->isSubmitted() && $configProfileCloneToForm->isValid()) {
-
-            if ($configProfileCloneToForm->offsetExists('no_clone') && $configProfileCloneToForm->get('no_clone')->isClicked()) {
-
-                $devicesToClonedToIds = [];
-                $devicesToDelete = [];
-
-                foreach ($devicesToClonedTo as $device) {
-
-                    $devicesToClonedToIds[] = $device->getId();
-
-                }
-
-                foreach ($devicesToClonedToIds as $deviceToDeleteId) {
-
-                    $devicesToDelete[] = $deviceToDeleteId;
-
-                }
-
-                if(!empty($devicesToDelete)){
-
-                    $result = $this->updateDevicesConfigProfile(null, $devicesToDelete);
-
-                }
-
-                if($result){
-
-                    $this->addFlash(
-                        'success',
-                        'Device cloning was removed.'
-                    );
-
-                }else{
-
-                    $this->addFlash(
-                        'danger',
-                        'Device cloning remove was unsuccessful.'
-                    );
-
-                }
-
-                return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-
-            } else {
-
-                $formData = $configProfileCloneToForm->getData();
-                $devicesToCloneTo = $formData['devices'];
-                $configProfileToClone = $device->configProfileAutomatic;
-
-                if (!$configProfileToClone) {
-
-                    $this->addFlash(
-                        'danger',
-                        'Device profile is empty and cannot be cloned.'
-                    );
-
-                    return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-                }
-
-                $devicesToClonedToIds = [];
-
-                foreach ($devicesToClonedTo as $device) {
-
-                    $devicesToClonedToIds[] = $device->getId();
-
-                }
-
-                $devicesCloneTo = [];
-
-                foreach ($devicesToCloneTo as $deviceCloneToId) {
-
-                    //if not exists
-                    if (!in_array($deviceCloneToId, $devicesToClonedToIds)) {
-
-                        $devicesCloneTo[] = $deviceCloneToId;
-
-                    }
-
-                    //Remove processed devices from array
-                    $key = array_search($deviceCloneToId, $devicesToClonedToIds);
-                    if (false !== $key) {
-                        unset($devicesToClonedToIds[$key]);
-                    }
-
-                }
-
-                if(!empty($devicesCloneTo)){
-
-                    $result = $this->updateDevicesConfigProfile($configProfileToClone->getId(), $devicesCloneTo);
-
-                }
-
-                $devicesToDelete = [];
-
-                foreach ($devicesToClonedToIds as $deviceToDeleteId) {
-
-                    $devicesToDelete[] = $deviceToDeleteId;
-
-                }
-
-                if(!empty($devicesToDelete)){
-
-                    $result = $this->updateDevicesConfigProfile(null, $devicesToDelete);
-
-                }
-
-                if(!isset($result)){
-
-                    $this->addFlash(
-                        'success',
-                        'No change processed for devices to be cloned to.'
-                    );
-
-                }else{
-
-                    if($result){
-
-                        $this->addFlash(
-                            'success',
-                            'Device profile was cloned to selected devices.'
-                        );
-
-                    }else{
-
-                        $this->addFlash(
-                            'danger',
-                            'Device profile cloned to selected failed.'
-                        );
-
-                    }
-
-                }
-
-                return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $deviceId]);
-
-            }
-
-        }
-
-       // dump($device->hasCustomFields());
-       // dd($device->customFieldDevice);
+			return $this->processAuthProfileFormSubmit($authProfilesForm, $managerRegistry, $device, $deviceId);
+		}
 
         return $this->render('device/detail.html.twig', [
             'device' => $device,
             'hostnameForm' => $hostnameForm->createView(),
             'fwForm' => $fwVersionForm->createView(),
             'deleteForm' => $deleteForm->createView(),
-            'isDevicesToCloneFromEmpty' => empty($devicesToCloneFrom),
-            'configProfileCloneFromForm' => $configProfileCloneFromForm->createView(),
-            'configProfileCloneToForm' => $configProfileCloneToForm->createView(),
+			'configProfilesForm' => $configProfileForm->createView(),
             'customModuleDownloadForm' => $customModuleDownloadForm->createView(),
             'labelsForm' => $labelsForm->createView(),
             'systemLabelsForm' => $systemLabelsForm->createView(),
@@ -891,7 +558,11 @@ class DeviceController extends BaseController
      * @param Device $device
      * @return RedirectResponse
      */
-    private function processCustomLabelsFormSubmit(FormInterface $labelsForm, ManagerRegistry $managerRegistry, Device $device): RedirectResponse
+    private function processCustomLabelsFormSubmit(
+		FormInterface $labelsForm,
+		ManagerRegistry $managerRegistry,
+		Device $device
+	): RedirectResponse
     {
         $formData = $labelsForm->getData();
         $deviceLabels = $formData['deviceLabels'];
@@ -1184,4 +855,281 @@ class DeviceController extends BaseController
         return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
     }
 
+	private function processConfigProfileFormSubmit(
+		FormInterface $configProfileForm,
+		Device $device,
+		ManagerRegistry $managerRegistry,
+		ConfigProfiles $configProfilesApi
+	): RedirectResponse
+	{
+
+		$configProfileData = $configProfileForm->getData();
+
+		$configProfile = $managerRegistry->getRepository(ConfigProfile::class)
+			->findOneBy(['id' => $configProfileData['config_profile']]);
+
+		if(!$configProfile){
+
+			$this->addFlash(
+				'danger',
+				'Nonexisting Config Profile given.'
+			);
+
+			return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+
+		}
+
+		if ($configProfileForm->offsetExists('unset') && $configProfileForm->get('unset')->isClicked()) {
+
+			try{
+
+				$configProfilesApi->unassignDeviceFromConfigProfile([$device->getId()]);
+
+			}catch (\Exception $exception){
+
+				$this->addFlash(
+					'danger',
+					'There was an error.'
+				);
+
+			}
+
+			$this->addFlash(
+				'success',
+				'Config Profile was successfully unassigned.'
+			);
+
+			return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+
+		}
+
+		try{
+
+			$configProfilesApi->assignDeviceToConfigProfile($configProfile->getId(), [$device->getId()]);
+
+			$this->addFlash(
+				'success',
+				'Config Profile was successfully assigned.'
+			);
+
+		}catch (\Exception $exception){
+
+			$this->logger->error($exception->getMessage());
+
+			$this->addFlash(
+				'danger',
+				'There was an error.'
+			);
+		}
+
+		return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+
+	}
+
+	/**
+	 * @param FormInterface $hostnameForm
+	 * @param Device $device
+	 * @param ManagerRegistry $managerRegistry
+	 * @return RedirectResponse
+	 */
+	private function processHostnameFormSubmit(
+		FormInterface $hostnameForm,
+		Device $device,
+		ManagerRegistry $managerRegistry
+	): RedirectResponse
+	{
+
+		// $form->getData() holds the submitted values
+		// but, the original `$task` variable has also been updated
+		$formData = $hostnameForm->getData();
+
+		$device->setHostnameDesired($formData['hostname']);
+		$managerRegistry->getManager()->persist($device);
+		$managerRegistry->getManager()->flush();
+
+		$this->addFlash(
+			'success',
+			'Hostname will be updated.'
+		);
+
+		return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+
+	}
+
+	/**
+	 * @param FormInterface $agentProfilesForm
+	 * @param ManagerRegistry $managerRegistry
+	 * @param AgentProfiles $agentProfilesApi
+	 * @param Device $device
+	 * @return RedirectResponse
+	 */
+	private function processAgentProfileFormSubmit(
+		FormInterface $agentProfilesForm,
+		ManagerRegistry $managerRegistry,
+		AgentProfiles $agentProfilesApi,
+		Device $device): RedirectResponse
+	{
+		$formData = $agentProfilesForm->getData();
+		$agentProfileId = $formData['agent_profile'];
+
+		$agentProfile = $managerRegistry->getRepository(AgentProfile::class)
+			->findOneBy(['id' => $agentProfileId]);
+
+		try{
+
+			$agentProfilesApi->assignDeviceAgentProfile($agentProfileId, [$device->getId()]);
+
+			$this->addFlash(
+				'success',
+				'Agent profile was updated.'
+			);
+
+		}catch (\Exception $exception){
+
+			$this->logger->error($exception->getMessage());
+
+			$this->addFlash(
+				'danger',
+				'Agent profile cannot be updated.'
+			);
+
+		}
+
+		return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+	}
+
+	/**
+	 * @param FormInterface $authProfilesForm
+	 * @param ManagerRegistry $managerRegistry
+	 * @param Device $device
+	 * @return RedirectResponse
+	 */
+	private function processAuthProfileFormSubmit(
+		FormInterface $authProfilesForm,
+		ManagerRegistry $managerRegistry,
+		Device $device,
+		): RedirectResponse
+	{
+		$formData = $authProfilesForm->getData();
+		$authProfileId = $formData['auth_profile'];
+
+		$authProfile = $managerRegistry->getRepository(AuthProfile::class)
+			->findOneBy(['id' => $authProfileId]);
+
+		$device->setAuthProfile($authProfile);
+		$managerRegistry->getManager()->persist($device);
+		$managerRegistry->getManager()->flush();
+
+		$this->addFlash(
+			'success',
+			'Auth profile was updated.'
+		);
+
+		return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+	}
+
+	/**
+	 * @param FormInterface $customModuleDownloadForm
+	 * @param Command $commandService
+	 * @param ManagerRegistry $managerRegistry
+	 * @param ParameterBagInterface $params
+	 * @param Device $device
+	 * @return RedirectResponse|BinaryFileResponse
+	 */
+	private function processCustomModuleDownloadFormSubmit(
+		FormInterface $customModuleDownloadForm,
+		Command $commandService,
+		ManagerRegistry $managerRegistry,
+		ParameterBagInterface $params,
+		Device $device
+	): RedirectResponse|BinaryFileResponse
+	{
+		$formData = $customModuleDownloadForm->getData();
+
+		$devId = $formData['deviceId'];
+		$deviceTypeId = $formData['deviceType'];
+
+		$exitCode = $commandService->runCustomizedAgentGenerator($devId);
+
+		if ($exitCode === 0) {
+
+			$deviceType = $managerRegistry->getRepository(DeviceType::class)->findOneBy(['id' => $deviceTypeId]);
+
+			$mapping = $deviceType->getDeviceTypeAgentMapping();
+			if (count($mapping) > 1) {
+
+				$this->addFlash(
+					'danger',
+					'No valid agent data given.'
+				);
+
+			} else {
+
+				$customizedAgentPath = $params->get('app.customizedAgentPath');
+				$agent = $mapping[0]->getDeviceAgent();
+
+				$file = $customizedAgentPath . $devId . DIRECTORY_SEPARATOR . $agent->getDirName() . DIRECTORY_SEPARATOR . $agent->getPackageName();
+
+				$response = new BinaryFileResponse($file);
+				$response->setContentDisposition(
+					ResponseHeaderBag::DISPOSITION_ATTACHMENT,
+					$agent->getPackageName()
+				);
+
+				return $response;
+			}
+
+		} else {
+
+			$this->addFlash(
+				'danger',
+				'The agent cannot be created.'
+			);
+
+		}
+
+		return $this->redirectToRoute('admin_devices_detail', ['deviceId' => $device->getId()]);
+	}
+
+	/**
+	 * @param ManagerRegistry $managerRegistry
+	 * @param ApiService $apiService
+	 * @param Device $device
+	 * @return RedirectResponse
+	 */
+	private function processDeleteFormSubmit(
+		ManagerRegistry $managerRegistry,
+		ApiService $apiService,
+		Device $device
+	): RedirectResponse
+	{
+		$snmpDevice = $managerRegistry->getRepository(SnmpDevice::class);
+
+		if ($apiService->deleteDevice($device->getId()) !== false) {
+
+			try {
+				$snmpDevice->removeSnmpDevice($device->getId());
+				$this->addFlash(
+					'success',
+					'Device was successfully deleted.'
+				);
+			} catch (\Exception $e) {
+				$this->addFlash(
+					'danger',
+					'Device was not deleted.'
+				);
+			}
+
+		} else {
+
+			$this->addFlash(
+				'danger',
+				'Device was not deleted.'
+			);
+
+		}
+
+		return $this->redirectToRoute('admin_devices');
+	}
+
 }
\ No newline at end of file
