@@ -7,11 +7,10 @@ use App\DataTable\CustomLabelDatatable;
 use App\DataTable\SystemLabelDatatable;
 use App\Form\LabelType;
 use Sg\DatatablesBundle\Datatable\DatatableFactory;
-use Sg\DatatablesBundle\Datatable\DatatableInterface;
 use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 #[Route('/admin/label', name: 'admin_label_')]
 class LabelController extends BaseController
