@@ -18,7 +18,7 @@ use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 #[Route(path: '/admin/agent-profile', name: 'admin_agent_profile')]
 class AgentProfileController extends BaseController
