@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\System;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
@@ -12,14 +14,18 @@ use Sg\DatatablesBundle\Datatable\DatatableInterface;
 use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 class EventLogController extends BaseController
 {
-    /**
-     * @return Response
-     * @throws \Exception
-     */
+	/**
+	 * @param Request $request
+	 * @param ManagerRegistry $managerRegistry
+	 * @param DatatableFactory $factory
+	 * @param DatatableResponse $responseService
+	 * @return Response
+	 * @throws \Exception
+	 */
     #[Route(path: '/admin/event-log', name: 'admin_event_log')]
     public function default(Request $request, ManagerRegistry $managerRegistry,
                             DatatableFactory $factory, DatatableResponse $responseService): Response{
