@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\System;
 
 use App\Exception\FileUploadException;
@@ -13,7 +15,7 @@ use Symfony\Component\HttpFoundation\File\UploadedFile;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\Process\Exception\ProcessFailedException;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as Controller;
 use Symfony\Component\HttpFoundation\Response;
 
@@ -36,17 +38,22 @@ class LicenseController extends Controller
     {
     }
 
-    /**
-     * @return RedirectResponse|Response
-     * @throws \Exception
-     */
+	/**
+	 * @param Request $request
+	 * @param ConfigRepository $configRepository
+	 * @param Command $commandService
+	 * @param ConfigurationService $configurationService
+	 * @return RedirectResponse|Response
+	 * @throws \Exception
+	 */
     #[Route(path: '/admin/system/license', name: 'admin_system_license')]
     public function default(
         Request $request,
         ConfigRepository $configRepository,
         Command $commandService,
         ConfigurationService $configurationService
-    ) {
+    ): RedirectResponse|Response
+	{
 
         try {
             $processDumpLicense = $commandService->checkLicense();
@@ -198,12 +205,12 @@ class LicenseController extends Controller
         ]);
     }
 
-    /**
-     * @param $licenseFile
-     * @return string
-     * @throws FileUploadException
-     */
-    private function uploadLicenseFile($licenseFile): string
+	/**
+	 * @param UploadedFile $licenseFile
+	 * @return string
+	 * @throws FileUploadException
+	 */
+    private function uploadLicenseFile(UploadedFile $licenseFile): string
     {
 
         try {
