@@ -14,6 +14,7 @@ use App\Repository\TypesValueTypeRepository;
 use App\Service\Api\Configuration;
 use App\Service\Command;
 use App\Service\ConfigurationService;
+use App\Service\TranslationService;
 use Psr\Log\LoggerInterface;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as Controller;
 use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
@@ -22,7 +23,7 @@ use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\Process\Exception\ProcessFailedException;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 class SettingsController extends Controller {
 
@@ -43,23 +44,26 @@ class SettingsController extends Controller {
 	 * @param Request $request
 	 * @param ConfigurationService $configurationService
 	 * @param Command $commandService
+	 * @param TranslationService $translationService
 	 * @return RedirectResponse|Response
+	 * @throws \JsonException
 	 */
     #[Route(path: '/admin/settings', name: 'admin_settings')]
-    public function default(Request $request, ConfigurationService $configurationService, Command $commandService): RedirectResponse|Response
+    public function default(Request $request, ConfigurationService $configurationService, Command $commandService, TranslationService $translationService): RedirectResponse|Response
 	{
 
         $settings = $this->getSettings($configurationService);
 
         $deviceTableColumnsChoices = [];
-        $availableDeviceTableColumns = DeviceDatatable::availableColumns;
+		$availableDeviceTableColumns = $translationService->getTranslatedStringsFromArray( DeviceDatatable::availableColumns);
+
         foreach ($availableDeviceTableColumns as $key => $column) {
             $deviceTableColumnsChoices[$column] = $key;
         }
 
         // Sort array of choices by actual order stored in db
         $sortingArr = $settings['deviceTableColumns'];
-        uasort($deviceTableColumnsChoices, fn($a, $b) => array_search($a, $sortingArr) <=> array_search($b, $sortingArr));
+        uasort($deviceTableColumnsChoices, static fn($a, $b) => array_search($a, $sortingArr, true) <=> array_search($b, $sortingArr, true));
 
         $settings['deviceTableColumnsChoices'] = $deviceTableColumnsChoices;
         $configFormData = $settings['configFormData'];
@@ -129,18 +133,23 @@ class SettingsController extends Controller {
         }
 
 		$configNames = [];
-		//Get group builder which is part of the form named 'config'
-		foreach ($settingsForm->all()['config'] as $item){
-			//Used to generate js to disable and enable items in the form
-			$configNames[] = $item->getName();
+
+		if(array_key_exists('config', $settingsForm->all())){
+
+			//Get group builder which is part of the form named 'config'
+			foreach ($settingsForm->all()['config'] as $item){
+				//Used to generate js to disable and enable items in the form
+				$configNames[] = $item->getName();
+			}
+
 		}
 
-        return $this->render('system/settings.html.twig', [
-            'settingsForm' => $settingsForm->createView(),
-            'configNames' => $configNames ?? null,
-            'nonWritableConfigData' => $this->getNonWritableConfigData($configFormData),
-            'deviceTableColumnsChoices' => $deviceTableColumnsChoices,
-        ]);
+		return $this->render('system/settings.html.twig', [
+			'settingsForm' => $settingsForm->createView(),
+			'configNames' => $configNames ?? null,
+			'nonWritableConfigData' => $this->getNonWritableConfigData($configFormData),
+			'deviceTableColumnsChoices' => $deviceTableColumnsChoices,
+		]);
     }
 
 	#[Route(path: '/admin/settings/dcl', name: 'admin_settings_dcl_atom')]
@@ -282,12 +291,17 @@ class SettingsController extends Controller {
         $this->redirectToRoute('admin_settings');
     }
 
-    /**
-     * @return array
-     */
+	/**
+	 * @return array
+	 * @throws \JsonException
+	 */
     private function getConfigFormData(): array {
 
         $config = $this->apiConfiguration->getConfiguration();
+
+		//dump($config);
+		//die();
+
         $types = $this->typesValueTypeRepository->getAllTypes();
 
         // Cannot get data from API
@@ -317,6 +331,11 @@ class SettingsController extends Controller {
         return $configFormData;
     }
 
+	/**
+	 * @param ConfigurationService $configurationService
+	 * @return array
+	 * @throws \JsonException
+	 */
     private function getSettings(ConfigurationService $configurationService): array
     {
 
