@@ -4,10 +4,14 @@ declare(strict_types=1);
 
 namespace App\Controller\Admin\System;
 
+use App\Entity\EventLog\EventType;
+use App\Event\ButtonTypeEventLogEvent;
 use App\Form\System\SystemStatusType;
 use App\Repository\TunnelWebRepository;
 use App\Service\Command;
 use App\Service\EnvConfigurationService;
+use Psr\EventDispatcher\EventDispatcherInterface;
+use Psr\Log\LoggerInterface;
 use Symfony\Bundle\FrameworkBundle\Controller\AbstractController as Controller;
 use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
@@ -17,15 +21,21 @@ use Symfony\Component\Routing\Attribute\Route;
 
 class StatusController extends Controller
 {
-    public function __construct(private readonly Command $commandService)
+    public function __construct(
+		private readonly Command $commandService,
+		private readonly LoggerInterface $logger,
+		private readonly EventDispatcherInterface $eventDispatcher
+	)
     {
     }
 
-    /**
-     * @param Request $request
-     * @param TunnelWebRepository $tunnelRepository
-     * @return Response
-     */
+	/**
+	 * @param EnvConfigurationService $envConfigurationService
+	 * @param Request $request
+	 * @param TunnelWebRepository $tunnelRepository
+	 * @return Response
+	 * @throws \Doctrine\DBAL\Exception
+	 */
     #[Route(path: '/admin/system/status', name: 'admin_system_status')]
     public function default(EnvConfigurationService $envConfigurationService,
 							Request $request, TunnelWebRepository $tunnelRepository): Response
@@ -96,6 +106,7 @@ class StatusController extends Controller
     {
         try {
             $isRestarted = $this->commandService->restartService();
+			$this->eventDispatcher->dispatch(new ButtonTypeEventLogEvent($this->getUser(), EventType::SYSTEM_SERVICE_RESTART_BUTTON_ID, 'Service Restart'), ButtonTypeEventLogEvent::NAME);
         } catch (ProcessFailedException $exception) {
             $this->addFlash(
                 'danger',
@@ -103,7 +114,7 @@ class StatusController extends Controller
             );
 
             return $this->redirectToRoute('admin_system_status');
-        }
+		}
 
         if (!$isRestarted) {
             $this->addFlash(
@@ -127,24 +138,28 @@ class StatusController extends Controller
      */
     public function startService(): RedirectResponse
     {
+
         try {
             $isStarted = $this->commandService->startService();
+			$this->eventDispatcher->dispatch(new ButtonTypeEventLogEvent($this->getUser(), EventType::SYSTEM_SERVICE_START_BUTTON_ID, 'Service Start'), ButtonTypeEventLogEvent::NAME);
         } catch (ProcessFailedException $exception) {
+			$this->logger->error($exception->getMessage(), ['StartDgService']);
             $this->addFlash(
                 'danger',
                 'Service start failed. Reason: ' . $exception->getMessage()
             );
 
             return $this->redirectToRoute('admin_system_status');
-        }
+        } /*catch (ExceptionInterface $e) {
+			$this->logger->error('Dispatch of Event:'. ButtonTypeEventLogMessageMessage::MESSAGE_NAME . ' with buttonId: ' . EventType::SYSTEM_SERVICE_START_BUTTON_ID . ' failed.');
+		}*/
 
-        if (!$isStarted) {
+		if (!$isStarted) {
             //throw new ProcessFailedException($process);
             $this->addFlash(
                 'danger',
                 'Service start failed.'
             );
-
             return $this->redirectToRoute('admin_system_status');
         }
 
@@ -160,6 +175,7 @@ class StatusController extends Controller
     {
         try {
             $isRestarted = $this->commandService->restartSnmpGatewayService();
+			$this->eventDispatcher->dispatch(new ButtonTypeEventLogEvent($this->getUser(), EventType::SNMP_SERVICE_RESTART_BUTTON_ID, 'SNMP Gateway restart'), ButtonTypeEventLogEvent::NAME);
         } catch (ProcessFailedException $exception) {
             $this->addFlash(
                 'danger',
@@ -167,7 +183,9 @@ class StatusController extends Controller
             );
 
             return $this->redirectToRoute('admin_system_status');
-        }
+		} /*catch (ExceptionInterface $e) {
+			$this->logger->error('Dispatch of Event:'. ButtonTypeEventLogMessageMessage::MESSAGE_NAME . ' with buttonId: ' . EventType::SNMP_SERVICE_RESTART_BUTTON_ID . ' failed.');
+		}*/
 
         if (!$isRestarted) {
             $this->addFlash(
@@ -189,6 +207,7 @@ class StatusController extends Controller
     {
         try {
             $isStarted = $this->commandService->startSnmpGatewayService();
+			$this->eventDispatcher->dispatch(new ButtonTypeEventLogEvent($this->getUser(), EventType::SNMP_SERVICE_START_BUTTON_ID, 'SNMP Gateway start'), ButtonTypeEventLogEvent::NAME);
         } catch (ProcessFailedException $exception) {
             $this->addFlash(
                 'danger',
@@ -196,7 +215,9 @@ class StatusController extends Controller
             );
 
             return $this->redirectToRoute('admin_system_status');
-        }
+		} /*catch (ExceptionInterface $e) {
+			$this->logger->error('Dispatch of Event:'. ButtonTypeEventLogMessageMessage::MESSAGE_NAME . ' with buttonId: ' . EventType::SNMP_SERVICE_START_BUTTON_ID . ' failed.');
+		}*/
 
         if (!$isStarted) {
             //throw new ProcessFailedException($process);
@@ -220,6 +241,7 @@ class StatusController extends Controller
     {
         try {
             $isStarted = $this->commandService->stopSnmpGatewayService();
+			$this->eventDispatcher->dispatch(new ButtonTypeEventLogEvent($this->getUser(), EventType::SNMP_SERVICE_STOP_BUTTON_ID, 'SNMP Gateway stop'), ButtonTypeEventLogEvent::NAME);
         } catch (ProcessFailedException $exception) {
             $this->addFlash(
                 'danger',
@@ -227,7 +249,9 @@ class StatusController extends Controller
             );
 
             return $this->redirectToRoute('admin_system_status');
-        }
+		} /*catch (ExceptionInterface $e) {
+			$this->logger->error('Dispatch of Event:'. ButtonTypeEventLogMessageMessage::MESSAGE_NAME . ' with buttonId: ' . EventType::SNMP_SERVICE_STOP_BUTTON_ID . ' failed.');
+		}*/
 
         if (!$isStarted) {
             //throw new ProcessFailedException($process);
