@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\System;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
@@ -8,20 +10,25 @@ use App\DataTable\UserDatatable;
 use Sg\DatatablesBundle\Datatable\DatatableFactory;
 use Sg\DatatablesBundle\Datatable\DatatableInterface;
 use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
+use Symfony\Component\HttpFoundation\JsonResponse;
+use Symfony\Component\HttpFoundation\RedirectResponse;
 use Symfony\Component\HttpFoundation\Request;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 use Symfony\Component\HttpFoundation\Response;
 
 class UserManagementController extends BaseController
 {
-    /**
-     * @return \Symfony\Component\HttpFoundation\JsonResponse|Response
-     * @throws \Exception
-     */
+	/**
+	 * @param Request $request
+	 * @param DatatableFactory $factory
+	 * @param DatatableResponse $responseService
+	 * @return JsonResponse|Response
+	 * @throws \Exception
+	 */
     #[Route(path: '/admin/user-management', name: 'admin_user_management')]
     public function default(Request $request, DatatableFactory $factory,
-                            DatatableResponse $responseService)
-    {
+                            DatatableResponse $responseService): JsonResponse|Response
+	{
 
         $isAjax = $request->isXmlHttpRequest();
         $this->filter = $request->query->get('column');
@@ -47,12 +54,13 @@ class UserManagementController extends BaseController
 
     }
 
-    /**
-     * @return \Symfony\Component\HttpFoundation\RedirectResponse
-     */
+	/**
+	 * @param Request $request
+	 * @return RedirectResponse
+	 */
     #[Route(path: '/admin/user-add', name: 'admin_user_add')]
-    public function addUser(Request $request)
-    {
+    public function addUser(Request $request): RedirectResponse
+	{
 
         return $this->redirectToRoute('admin_user_management');
 
