@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\Tools;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
@@ -15,7 +17,7 @@ use Sg\DatatablesBundle\Datatable\DatatableFactory;
 use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 #[Route('/admin/tools', name: 'admin_tool_')]
 class AuthProfileManagementController extends BaseController
