@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\Tools;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
@@ -15,7 +17,7 @@ use Sg\DatatablesBundle\Datatable\DatatableFactory;
 use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 #[Route('/admin/tools', name: 'admin_tool_')]
 class SimCardManagementController extends BaseController
@@ -61,9 +63,14 @@ class SimCardManagementController extends BaseController
         ]);
     }
 
-    /**
-     * @throws SimCardNotFoundException
-     */
+	/**
+	 * @param Request $request
+	 * @param int $simCardId
+	 * @param DatatableFactory $factory
+	 * @param DatatableResponse $responseService
+	 * @return Response
+	 * @throws SimCardNotFoundException
+	 */
     #[Route(path: '/sim-cards/edit/{simCardId}', name: 'sim_cards_edit')]
     public function simCardEdit(
         Request $request,
@@ -97,7 +104,7 @@ class SimCardManagementController extends BaseController
         if ($form->isSubmitted() && $form->isValid()) {
 
             $requestData = $request->request->all()['sim_card'];
-            $deviceId = (array_key_exists('device', $requestData)) ? $requestData['device'] : null;
+            $deviceId = $requestData['device'] ?? null;
             $formData = $form->getData();
             $em = $this->managerRegistry->getManager();
 
@@ -113,16 +120,15 @@ class SimCardManagementController extends BaseController
                 $em->persist($simCard);
                 $em->flush();
             } catch (UniqueConstraintViolationException $e) {
-                dump($e->getMessage());
-                die();
-
                 $this->addFlash(
                     'danger',
-                    'Cannot update: ',
+                    'Cannot update: ' . $e->getMessage(),
                 );
             } catch (\Exception $e) {
-                dump($e->getMessage());
-                die();
+				$this->addFlash(
+					'danger',
+					'Cannot update: ' . $e->getMessage(),
+				);
             }
 
             $this->addFlash(
