@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace App\Controller\Admin\Tools;
 
 use App\Bundles\Sg\DatatablesBundle\Response\DatatableResponse;
@@ -16,7 +18,7 @@ use Sg\DatatablesBundle\Datatable\DatatableFactory;
 use Sg\DatatablesBundle\Response\DatatableQueryBuilder;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
-use Symfony\Component\Routing\Annotation\Route;
+use Symfony\Component\Routing\Attribute\Route;
 
 #[Route('/admin/tools', name: 'admin_tool_')]
 class SmsSenderController extends BaseController
@@ -24,9 +26,13 @@ class SmsSenderController extends BaseController
 
     private const ARBITRARY_SMS_ID = '1';
 
-    /**
-     * @throws \Exception
-     */
+	/**
+	 * @param Request $request
+	 * @param DatatableFactory $factory
+	 * @param DatatableResponse $responseService
+	 * @return Response
+	 * @throws \Exception
+	 */
     #[Route(path: '/sms-sender', name: 'sms_sender_index')]
     public function smsSenderAction(Request $request,
                                     DatatableFactory $factory,
@@ -35,8 +41,6 @@ class SmsSenderController extends BaseController
         $isAjax = $request->isXmlHttpRequest();
         $this->filter = $request->query->get('column');
 
-        $devices = $this->managerRegistry->getRepository(Device::class)->getDevices();
-
         $datatable = $factory->create(SmsHistoryDatatable::class);
         $datatable->buildDatatable();
 
@@ -57,6 +61,11 @@ class SmsSenderController extends BaseController
 
     }
 
+	/**
+	 * @param Request $request
+	 * @param ApiService $apiService
+	 * @return Response
+	 */
     #[Route(path: '/sms-sender/send', name: 'sms_sender_send')]
     public function smsSendAction(Request $request, ApiService $apiService): Response {
 
@@ -72,7 +81,7 @@ class SmsSenderController extends BaseController
             $destinationType = $requestData['destination_type'] ?? null;
             $deviceId = $requestData['device'] ?? null;
             $smsTemplateId = $requestData['template'] ?? null;
-            $smsSimcardId = $requestData['destination'] ?? null;
+            $smsSimCardId = $requestData['destination'] ?? null;
             $msisdnText = $requestData['msisdn'] ?? null;
             $customSmsText = $requestData['custom_text'] ?? null;
 
@@ -86,6 +95,10 @@ class SmsSenderController extends BaseController
 
                 $device = $this->managerRegistry->getRepository(Device::class)->findOneBy(['id' => $deviceId]);
 
+				if(!$device){
+					throw new \Exception('Device not found.');
+				}
+
                 if($smsTemplateId !== self::ARBITRARY_SMS_ID){
                     $smsTemplate = $this->managerRegistry->getRepository(SmsTemplate::class)->findOneBy(['id' => $smsTemplateId]);
                     $smsText = $smsTemplate->getLabel();
@@ -93,8 +106,10 @@ class SmsSenderController extends BaseController
                     $smsText = $customSmsText;
                 }
 
+				$msisdn = '';
+
                 if($destinationType === 'Device'){
-                    $simCard = $this->managerRegistry->getRepository(SimCard::class)->findOneBy(['id' => $smsSimcardId]);
+                    $simCard = $this->managerRegistry->getRepository(SimCard::class)->findOneBy(['id' => $smsSimCardId]);
                     if($simCard)
                         $msisdn = $simCard->getMsisdn();
                 }else {
@@ -113,7 +128,7 @@ class SmsSenderController extends BaseController
 
                 try{
 
-                    $apiService->sendSms($deviceId, $msisdn, $netDev->getId(), $smsText);
+                    $apiService->sendSms($device->getId(), $msisdn, $netDev->getId(), $smsText);
 
                 }catch (\Exception $e){
 
