@@ -22,7 +22,8 @@ abstract class BaseDatatable extends AbstractDatatable
     public const ICON_DOWNLOAD = ' fas fa-download';
     public const ICON_UPLOAD = ' fas fa-upload';
 	public const ICON_MANAGE = ' fas fa-indent';
-    public const DATETIME_FORMAT = 'DD.MM.YYYY, HH:mm:ss';
+    //public const DATETIME_FORMAT = 'DD.MM.YYYY, HH:mm:ss'; //used by momentum
+    public const DATETIME_FORMAT = 'd.m.Y, H:i:s';
 
     /**
      * @var string
@@ -34,34 +35,37 @@ abstract class BaseDatatable extends AbstractDatatable
      */
     protected string $name;
 
-    /**
-     * {@inheritdoc}
-     */
+	/**
+	 * {@inheritdoc}
+	 * @throws \Exception
+	 */
     public function buildDatatable(array $options = []): void
     {
-        $this->language->set(array(
+        $this->language->set([
             'cdn_language_by_locale' => false,
-        ));
+        ]);
 
-        $this->ajax->set(array());
+        $this->ajax->set([]);
 
-        $this->options->set(array(
-            //'dom' => 'Bfrtip',
-            'dom' => '<"top"Bfi>rt<"bottom"lp><"clear">',
-            'classes' => Style::BOOTSTRAP_4_STYLE,
-            'individual_filtering' => true,
-            'individual_filtering_position' => 'head',
-            'order_cells_top' => true,
-            'length_menu' => [10, 25, 50, 100, 500],
-            'page_length' => 50,
-        ));
+		$this->options->set([
+			//'dom' => 'Bfrtip',
+			'dom' => '<"dt-top"Bfi>rt<"dt-layout-row"l><"dt-layout-cell dt-layout-end"p><"clear">',
+			'classes' => Style::BOOTSTRAP_4_STYLE,
+			'individual_filtering' => true,
+			'individual_filtering_position' => 'head',
+			'fixed_header' => true,
+			//'fixed_columns' => '{start: 2,end: 1}',
+			'order_cells_top' => true,
+			'length_menu' => [10, 25, 50, 100, 500],
+			'page_length' => 50,
+		]);
 
-        $this->features->set(array(
+        $this->features->set([
             'processing' => true,
             'scroll_x' => true,
-        ));
+        ]);
 
-        $this->extensions->set(array(
+        $this->extensions->set([
             'select' => array(
                 'blurable' => false,
                 'class_name' => 'selected',
@@ -83,7 +87,7 @@ abstract class BaseDatatable extends AbstractDatatable
                     ),
                 ),
             ),
-        ));
+        ]);
     }
 
     /**
