@@ -11,6 +11,7 @@ use App\DataTable\Column\CustomArrayColumn;
 use App\DataTable\Column\CustomDeviceFreshnessColumn;
 use App\DataTable\Column\CustomDeviceStatusColumn;
 use App\DataTable\Column\CustomIpAddressesArrayColumn;
+use App\DataTable\Column\CustomLinkColumn;
 use App\DataTable\Column\CustomMonitoringGroupArrayColumn;
 use App\Entity\Device\VDevice;
 use Sg\DatatablesBundle\Datatable\Column\ActionColumn;
@@ -38,7 +39,7 @@ class DeviceDatatable extends BaseDatatable
         'IpAddresses' => 'Ip Addresses', 'MonitoringGroups' => 'MonitoringGroups',
         'ConfigProfile' => 'Config profile', 'StatsSyncStatusDescription' => 'Sync Status',
         'StatLiveMissCountDescription' => 'Freshness', 'SerialNumber' => 'Serial Number',
-        'MacAddress' => 'Mac Address', self::tableColumnName_SnmpName => self::username_SnmpName,
+        self::tableColumnName_SnmpName => self::username_SnmpName,
         'Model' => 'Model', 'HostName' => 'Host Name', 'Uuid' => 'UuId',
         'Iccid' => 'IccId', 'ActiveSim' => 'Active Sim', 'SignalStrength' => 'Signal Strength', 'SignalQuality' => 'Signal Quality',
 		'SignalCsq' => 'Signal CSQ', 'SignalRssi' => 'Signal RSSI',
@@ -80,9 +81,10 @@ class DeviceDatatable extends BaseDatatable
 
         $this->initData($options);
 
-        parent::buildDatatable($options);
+		parent::buildDatatable();
 
         $this->options->setOrder([1,'asc']); //this is fixed by custom template to inject it before table data
+		$this->options->setFixedColumns('{start: 2,end: 1}');
 
         if (!$parentCall) {
             $this->extensions->set(
@@ -446,26 +448,6 @@ class DeviceDatatable extends BaseDatatable
 
         }
 
-       /* $this->getColumnNote1();
-        $this->getColumnNote2();
-        $this->getColumnNote3();*/
-
-        /*$this->getColumnByName('devId');
-        $this->getColumnByName('name');
-        $this->getColumnByName('devTypeName');
-        $this->getColumnByName('OsVerOsTypeName');
-        $this->getColumnByName('OsVerVersion');
-        $this->getColumnByName('Labels');
-        $this->getColumnMonitoringGroups();*/
-
-        //$this->getColumnByName('MacAddr');
-        //$this->getColumnByName('Serial');
-        //$this->getColumnByName('HostName');
-        //$this->getColumnByName('Uuid');
-
-       /* $this->getColumnByName('ConfigProfileAutomaticDevId');
-        $this->getColumnByName('StatsSyncStatusDescription');
-        $this->getColumnByName('StatLiveMissCountDescription');*/
     }
 
     private function getColumnByName(string $name): void
@@ -698,7 +680,7 @@ class DeviceDatatable extends BaseDatatable
                         'cancel_button' => true,
                     ],
                 ],
-                'editable' => [
+                /*'editable' => [
                     CustomTextEditable::class,[
                         'url' => 'app_datatables_edit',
                         'maxlength' => 64, //maxlength custom implementation
@@ -715,7 +697,7 @@ class DeviceDatatable extends BaseDatatable
                         },
                         'mode' => 'inline',
                     ],
-                ],
+                ],*/
             ]
         );
     }
@@ -765,11 +747,6 @@ class DeviceDatatable extends BaseDatatable
         );
     }
 
-    private function getColumnMacAddress(): void
-    {
-        $this->addDefaultTextColumn('macAddr', 'MAC');
-    }
-
     private function getColumnSerialNumber(): void
     {
         $this->addDefaultTextColumn('serial', 'SN');
@@ -830,7 +807,7 @@ class DeviceDatatable extends BaseDatatable
 
     private function getColumnSignalStrength(): void
     {
-        $this->addDefaultTextColumn('stats.signalStrength', 'Signal signalStrength');
+        $this->addDefaultTextColumn('stats.signalStrength', 'Signal Strength');
     }
 
     private function getColumnSignalQuality()
@@ -855,7 +832,7 @@ class DeviceDatatable extends BaseDatatable
 
 	private function getColumnSimIpaddr(): void
 	{
-		$this->addDefaultTextColumn('stats.simIpaddr', 'SIM IPv4');
+		$this->addDefaultTextLinkColumn('stats.simIpaddr', 'SIM IPv4');
 	}
 
 	private function getColumnSimIp6addr(): void
@@ -968,4 +945,26 @@ class DeviceDatatable extends BaseDatatable
         );
     }
 
+	private function addDefaultTextLinkColumn(string $dqlColumn, string $title, string $defaultContentValue = ''): void
+	{
+
+		$this->columnBuilder->add(
+			$dqlColumn,
+			CustomLinkColumn::class,
+			[
+				'name' => strtolower(str_replace(" ", "", $title)),
+				'link' => 'https://',
+				'title' => $title,
+				'default_content' => $defaultContentValue,
+				'type_of_field' => 'string',
+				'width' => '100%;',
+				'filter' => [
+					TextFilter::class,[
+						'cancel_button' => true,
+					],
+				],
+			]
+		);
+	}
+
 }
