@@ -2,6 +2,7 @@
 
 namespace App\DataTable;
 
+use App\Entity\MonitoringGroup\MonitoringGroup;
 use Sg\DatatablesBundle\Datatable\Column\ActionColumn;
 use Sg\DatatablesBundle\Datatable\Column\Column;
 use Sg\DatatablesBundle\Datatable\Editable\TextEditable;
@@ -14,7 +15,7 @@ use Sg\DatatablesBundle\Datatable\Filter\TextFilter;
 class MonitoringGroupDatatable extends BaseDatatable
 {
 
-    protected string $entity = \App\Entity\MonitoringGroup\MonitoringGroup::class;
+    protected string $entity = MonitoringGroup::class;
     protected string $name = 'mongrp_datatable';
 
     /**
