@@ -45,7 +45,7 @@ class Device
     /**
      * @var string|null
      */
-    #[ORM\Column(type: Types::STRING, length: 32, nullable: true)]
+    #[ORM\Column(type: Types::STRING, length: 32, nullable: true, options: ['datatable_editable' => true])]
     public ?string $name = null;
 
     /**
@@ -77,10 +77,11 @@ class Device
     public ?DeviceOsVersion $osVerDesired = null;
 
     /**
+	 * @deprecated to be deleted
      * @var string|null
      */
-    #[ORM\Column(name: 'macaddr', type: Types::STRING, length: 12, nullable: true)]
-    public ?string $macAddr = null;
+    //#[ORM\Column(name: 'macaddr', type: Types::STRING, length: 12, nullable: true)]
+    //public ?string $macAddr = null;
 
     /**
      * @var string|null
@@ -121,7 +122,7 @@ class Device
     /**
      * @var DeviceStats
      */
-    #[ORM\OneToOne(mappedBy: 'device', targetEntity: DeviceStats::class)]
+    #[ORM\OneToOne(targetEntity: DeviceStats::class, mappedBy: 'device')]
     //#[ORM\JoinColumn(name: 'id_device', referencedColumnName: 'id_device')] //Deprecated for v3 on mappedBy side to use joinColumn
     public DeviceStats $stats;
 
@@ -154,77 +155,77 @@ class Device
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: MonitoringGroupMapping::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: MonitoringGroupMapping::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $monitoringGroupMappings;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: DeviceNetDev::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: DeviceNetDev::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $netDevices;
 
     /**
      * @var DeviceNote|null
      */
-    #[ORM\OneToOne(mappedBy: 'device', targetEntity: DeviceNote::class, cascade: ['persist'])]
+    #[ORM\OneToOne(targetEntity: DeviceNote::class, mappedBy: 'device', cascade: ['persist'])]
     //#[ORM\JoinColumn(name: 'id_device', referencedColumnName: 'id_device', nullable: true)]
     public ?DeviceNote $noteDevice = null;
 
     /**
      * @var DeviceModel|null
      */
-    #[ORM\OneToOne(targetEntity: DeviceModel::class, cascade: ['persist'], mappedBy: "device")]
-   /* #[ORM\JoinColumn(name: 'model', referencedColumnName: 'id')]*/
-    public ?DeviceModel $model = null;
+	#[ORM\ManyToOne(targetEntity: DeviceModel::class, inversedBy: 'devices')]
+	#[ORM\JoinColumn(name: 'model')]
+	public ?DeviceModel $model = null;
 
     /**
      * @var DeviceCustomField|null
      */
-    #[ORM\OneToOne(mappedBy: 'device', targetEntity: DeviceCustomField::class, cascade: ['persist'])]
+    #[ORM\OneToOne(targetEntity: DeviceCustomField::class, mappedBy: 'device', cascade: ['persist'])]
     //#[ORM\JoinColumn(name: 'id_device', referencedColumnName: 'id_device', nullable: true)] //Deprecations for v3
     public ?DeviceCustomField $customFieldDevice = null;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'targetDevice', targetEntity: Alert::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: Alert::class, mappedBy: 'targetDevice', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $alerts;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: LabelDeviceMap::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: LabelDeviceMap::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $labels;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: SystemLabelDeviceMap::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: SystemLabelDeviceMap::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $systemLabels;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'deviceUser', targetEntity: SimCard::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: SimCard::class, mappedBy: 'deviceUser', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $deviceSimCards;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'deviceLastSeen', targetEntity: SimCard::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: SimCard::class, mappedBy: 'deviceLastSeen', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $deviceLastSeen;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: SmsHistory::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: SmsHistory::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $smsHistoryDevice;
 
@@ -238,28 +239,28 @@ class Device
     /**
      * @var ConfigProfile|null
      */
-    #[ORM\OneToOne(mappedBy: 'automatic', targetEntity: ConfigProfile::class, cascade: ['persist'])]
+    #[ORM\OneToOne(targetEntity: ConfigProfile::class, mappedBy: 'automatic', cascade: ['persist'])]
     //#[ORM\JoinColumn(name: 'automatic_profile', nullable: true)]
     public ?ConfigProfile $configProfileAutomatic = null;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: Tunnels::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: Tunnels::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $webTunnels;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: DataChangeLog::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: DataChangeLog::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $dataChangeLogs;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'device', targetEntity: DeviceUserModule::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: DeviceUserModule::class, mappedBy: 'device', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id_device')]
     public Collection $userModules;
 
@@ -349,15 +350,6 @@ class Device
 
     }
 
-    /**
-     * @return string|null
-     */
-    public function getMacAddr(): ?string {
-
-        return $this->macAddr;
-
-    }
-
     /**
      * @return string|null
      */
@@ -512,6 +504,14 @@ class Device
 
     }
 
+	/**
+	 * @return DeviceCustomField|null
+	 */
+	public function getCustomFieldDevice(): ?DeviceCustomField
+	{
+		return $this->customFieldDevice;
+	}
+
     /**
      * @return ArrayCollection
      */
