@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace App\Entity\Device;
 
+use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
@@ -25,12 +27,18 @@ class DeviceModel {
     #[ORM\Column(type: Types::STRING, length: 128, nullable: true)]
     public ?string $model = null;
 
-    /**
-     * @var Device
-     */
-    #[ORM\OneToOne(targetEntity: Device::class, inversedBy: 'model')]
-    #[ORM\JoinColumn(name: 'id', referencedColumnName: 'id_device', nullable: true)]
-    public Device $device;
+	/**
+	 * @var Collection
+	 */
+	#[ORM\OneToMany(targetEntity: Device::class, mappedBy: 'model', cascade: ['persist'])]
+	#[ORM\JoinColumn(name: 'id', referencedColumnName: 'model')]
+	public Collection $devices;
+
+	public function __construct(){
+
+		$this->devices = new ArrayCollection();
+
+	}
 
     /**
      * @return int|null
@@ -47,4 +55,11 @@ class DeviceModel {
 		return $this->model;
 	}
 
+	/**
+	 * @return Collection
+	 */
+	public function getDevices(): Collection
+	{
+		return $this->devices;
+	}
 }
