@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace App\Entity\Device;
 
 use App\Entity\Device;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'agent_device_type_map')]
@@ -15,7 +16,7 @@ class DeviceTypeAgentMapping
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
