@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace App\Entity\EventLog;
 
+use App\Entity\User\User;
 use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
@@ -22,7 +23,7 @@ class EventLog
     /**
      * @var EventType
      */
-    #[ORM\ManyToOne(targetEntity: 'EventType', inversedBy: 'events')]
+    #[ORM\ManyToOne(targetEntity: EventType::class, inversedBy: 'events')]
     #[ORM\JoinColumn(name: 'evtype')]
     public EventType $eventType;
 
@@ -48,6 +49,10 @@ class EventLog
     #[ORM\Column(type: Types::STRING, length: 64, nullable: false)]
     public ?string $msg = null;
 
+	#[ORM\ManyToOne(targetEntity: User::class, inversedBy: 'events')]
+	#[ORM\JoinColumn(name: 'user_id')]
+	public User $user;
+
     /**
      * @var \DateTime
      */
@@ -134,4 +139,26 @@ class EventLog
     {
         $this->msg = $msg;
     }
+
+	/**
+	 * @return string|null
+	 */
+	/**
+	 * @return User
+	 */
+	public function getUser(): User
+	{
+		return $this->user;
+	}
+
+	/**
+	 * @param string|null $userId
+	 */
+	/**
+	 * @param User $user
+	 */
+	public function setUser(User $user): void
+	{
+		$this->user = $user;
+	}
 }
