@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace App\Entity\Product;
 
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'product_flags_license_status')]
@@ -13,14 +14,14 @@ class ProductFlagsLicenseStatus
     /**
      * @var integer
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     private readonly int $id;
 
     /**
      * @var string
      */
-    #[ORM\Column(name: 'description', type: 'text')]
+    #[ORM\Column(name: 'description', type: Types::TEXT)]
     public string $description;
 
 }
\ No newline at end of file
