@@ -7,6 +7,7 @@ namespace App\Entity\Types;
 use App\Entity\Device;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'liveness_misscount')]
@@ -16,7 +17,7 @@ class LivenessMisscount
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -24,13 +25,13 @@ class LivenessMisscount
     /**
      * @var string
      */
-    #[ORM\Column(type: 'string', length: 64, nullable: false)]
+    #[ORM\Column(type: Types::STRING, length: 64, nullable: false)]
     public string $description;
 
     /**
      * @var Collection
      */
-    #[ORM\OneToMany(mappedBy: 'liveMissCount', targetEntity: Device\DeviceStats::class, cascade: ['persist'])]
+    #[ORM\OneToMany(targetEntity: Device\DeviceStats::class, mappedBy: 'liveMissCount', cascade: ['persist'])]
     #[ORM\JoinColumn(name: 'id')]
     public Collection $devicesStats;
 
