@@ -14,6 +14,7 @@ use App\Entity\Types\LivenessMisscount;
 use App\Entity\Types\LivenessTime;
 use App\Entity\Types\TypesOperator;
 use Doctrine\ORM\EntityManagerInterface;
+use Doctrine\Persistence\ManagerRegistry;
 use Symfony\Component\Form\AbstractType;
 use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
 use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
@@ -36,18 +37,18 @@ class AlertType extends AbstractType
     public const INPUT_NAME_NUMFIRST = 'numFirst';
     public const INPUT_NAME_NUMSECOND = 'numSecond';
 
-    private EntityManagerInterface $em;
-
     private ?string $caller = null;
 
     private FormInterface $form;
+	private ?Alert $alert;
 
-    /**
-     * @param EntityManagerInterface $em
-     */
-    public function __construct(EntityManagerInterface $em){
-
-        $this->em = $em;
+	/**
+	 * @param EntityManagerInterface $em
+	 * @param ManagerRegistry $managerRegistry
+	 */
+    public function __construct(private readonly EntityManagerInterface $em,
+								private readonly ManagerRegistry        $managerRegistry)
+	{
 
     }
 
@@ -65,24 +66,26 @@ class AlertType extends AbstractType
 
     }
 
-    /**
-     * @param FormInterface $form
-     * @param Alert|null $alert
-     * @param AlertTargetType|null $targetType
-     * @param AlertTargetSpec|null $targetSpec
-     * @param null $targetAmount
-     * @param \App\Entity\Device\Device|null $targetDevice
-     * @param MonitoringGroup|null $targetMonitoringGroup
-     * @param TypesOperator|null $firstOperator
-     * @param null $numFirst
-     * @param TypesOperator|null $secondOperator
-     * @param null $numSecond
-     */
-    protected function addElements(FormInterface   $form, Alert $alert = null, AlertTargetType $targetType = null,
-                                    AlertTargetSpec $targetSpec = null, $targetAmount = null,
-                                    Device          $targetDevice = null, MonitoringGroup $targetMonitoringGroup = null,
-                                    TypesOperator   $firstOperator = null, $numFirst = null,
-                                    TypesOperator   $secondOperator = null, $numSecond = null, $enabled = false): void
+	/**
+	 * @param FormInterface $form
+	 * @param Alert|null $alert
+	 * @param AlertTargetType|null $targetType
+	 * @param AlertTargetSpec|null $targetSpec
+	 * @param $targetAmount
+	 * @param Device|null $targetDevice
+	 * @param MonitoringGroup|null $targetMonitoringGroup
+	 * @param TypesOperator|null $firstOperator
+	 * @param $numFirst
+	 * @param TypesOperator|null $secondOperator
+	 * @param $numSecond
+	 * @param Bool $enabled
+	 * @return void
+	 */
+    protected function addElements(FormInterface   $form, ?Alert $alert = null, ?AlertTargetType $targetType = null,
+                                    ?AlertTargetSpec $targetSpec = null, $targetAmount = null,
+                                    ?Device          $targetDevice = null, ?MonitoringGroup $targetMonitoringGroup = null,
+                                    ?TypesOperator   $firstOperator = null, $numFirst = null,
+                                    ?TypesOperator   $secondOperator = null, $numSecond = null, bool $enabled = false): void
     {
 
         $this->form = $form;
@@ -129,7 +132,9 @@ class AlertType extends AbstractType
         $targetTypeChoices = [];
         foreach ($targetTypeResult as $item){
 
-            if($item->getId() === 0) continue;
+            if($item->getId() === 0) {
+				continue;
+			}
             $targetTypeChoices[$item->getName()] = $item->getId();
 
         }
@@ -153,16 +158,17 @@ class AlertType extends AbstractType
 
             if($targetType->getId() === self::TARGET_TYPE_DEVICE){
 
-                $devicesResult = $this->em->getRepository(Device::class)->findBy(['deleted' => '0']);
+                $devices = $this->managerRegistry->getRepository(Device::class)->getDevices();
 
                 $devicesChoices = [];
                 $deviceChoicesAttr = [];
-                foreach ($devicesResult as $item){
 
-                    $devicesChoices[$item->getDevId()] = $item->getId();
-                    $deviceChoicesAttr[$item->getDevId()] = ['data-description' => $item->getName()];
+				foreach ($devices as $item){
 
-                }
+					$devicesChoices[$item['devid']] = $item['id_device'];
+					$deviceChoicesAttr[$item['devid']] = ['data-description' => $item['name']];
+
+				}
 
                 $form->add('targetDevice', ChoiceType::class, [
                     'label' => 'Target Device',
@@ -196,13 +202,24 @@ class AlertType extends AbstractType
 
             }
 
-            $targetSpecResult = $this->em->getRepository(AlertTargetMap::class)->findBy(['targetType' => $targetType->getId()]);
+            $targetSpecMapResult = $this->em->getRepository(AlertTargetMap::class)->findBy(
+				['targetType' => $targetType->getId()], []
+			);
+
+			$targetSpecsIds = array_map(fn($targetSpec) => $targetSpec->getTargetSpec()->getId(), $targetSpecMapResult);
+
+			$targetSpecResult = $this->em->getRepository(AlertTargetSpec::class)->findBy(
+				['id' => $targetSpecsIds], ['displayOrder' => 'ASC']
+			);
+
 
             $targetSpecsChoices = [];
             foreach ($targetSpecResult as $item){
 
-                if($item->getTargetSpec()->getId() === 0) continue;
-                $targetSpecsChoices[$item->getTargetSpec()->getName()] = $item->getTargetSpec()->getId();
+                if($item->getId() === 0) {
+					continue;
+				}
+                $targetSpecsChoices[$item->getName()] = $item->getId();
 
             }
 
@@ -296,7 +313,7 @@ class AlertType extends AbstractType
             $targetMonitoringGroup = $this->em->getRepository(MonitoringGroup::class)->findOneBy(['id' => $data['targetMonitoringGroup']]);
         }
         if(isset($data['targetDevice'])){
-            $targetDevice = $this->em->getRepository(MonitoringGroup::class)->findOneBy(['id' => $data['targetDevice']]);
+            $targetDevice = $this->em->getRepository(Device::class)->findOneBy(['id' => $data['targetDevice']]);
         }
         if(isset($data['operFirst'])){
             $operFirst = $this->em->getRepository(TypesOperator::class)->findOneBy(['id' => $data['operFirst']]);
@@ -327,7 +344,11 @@ class AlertType extends AbstractType
         $targetMonitoringGroup = $alert->getTargetMonitoringGroup() ?: null;
         $firstOperator = $alert->getOperFirst() ? $alert->operFirst : null;
         $secondOperator = $alert->getOperSecond() ? $alert->operSecond : null;
-        $numFirst = (!is_null($alert->getNumFirst())) ? $alert->getNumFirst(): null;
+		if($targetSpec && $targetSpec->getValType()->getName() === 'string'){
+			$numFirst = (!is_null($alert->getStringFirst())) ? $alert->getStringFirst(): null;
+		}else{
+			$numFirst = (!is_null($alert->getNumFirst())) ? $alert->getNumFirst(): null;
+		}
         $numSecond = (!is_null($alert->getNumSecond())) ? $alert->getNumSecond(): null;
         //If create show enabled, otherwise respect settings of entity
         $enabled = ($alert->getId()) ? $alert->getEnabled() : true;
@@ -376,12 +397,12 @@ class AlertType extends AbstractType
 
     }
 
-    /**
-     * @param AlertTargetSpec $targetSpec
-     * @param string $inputName
-     * @param $dataValue
-     * @return void
-     */
+	/**
+	 * @param AlertTargetSpec $targetSpec
+	 * @param string $inputName
+	 * @param string|null $dataValue
+	 * @return void
+	 */
     private function getInput(AlertTargetSpec $targetSpec, string $inputName, ?string $dataValue): void {
 
         $valueType = $targetSpec->getValtype()->getName();
@@ -412,7 +433,7 @@ class AlertType extends AbstractType
         }elseif ($valueType === 'string'){
 
             $this->form->add($inputName, TextType::class, [
-                'label' => str_replace('#', 'Number', $label),
+                'label' => str_replace('#', 'Text', $label),
                 'required' => true,
                 'data' => $dataValue,
                 'mapped' => false,
