@@ -21,8 +21,8 @@ class DeleteType extends AbstractType
 
         $builder
             ->add('delete', SubmitType::class, [
-                'label' => '<i class="fas fa-trash"></i> ' . $text,
-                'label_html' => true,
+                'label' =>  $text,
+				'icon' => 'fas fa-trash',
                 'block_prefix' => 'modal_footer', 'attr' => ['class' => 'btn btn-danger'],])
         ;
 
