@@ -35,8 +35,8 @@ class DeviceAuthProfileType extends AbstractType
                     'attr' => ['class' => 'form-control-sm'],
                 ])
                 ->add('save', SubmitType::class, [
-                    'label' => '<i class="fas fa-bars-progress"></i> Set',
-                    'label_html' => true,
+                    'label' => 'Set',
+					'icon' => 'fas fa-bars-progress',
                     'attr' => ['class' => 'btn-primary btn-sm'],
                     'block_prefix' => 'modal_footer'
                 ])
