@@ -46,8 +46,9 @@ class DeviceCustomLabelType extends AbstractType
             ])
 
             ->add('save', SubmitType::class, [
-				'label' => '<i class="fas fa fa-tags"></i> Set ',
+				'label' => 'Set',
 				'label_html' => true,
+				'icon' => 'fas fa fa-tags',
                 'block_prefix' => 'modal_footer'
 			])
         ;
