@@ -28,8 +28,8 @@ class DeviceCustomModuleDownloadType extends AbstractType
                 'data' => $device->getDevType()->getId(),
             ))
             ->add('download', SubmitType::class, [
-                'label' => '<i class="fas fa-download"></i> Download preset agent',
-                'label_html' => true,
+                'label' => 'Download preset agent',
+				'icon' => 'fas fa-download',
                 'attr' => ['class' => 'btn-primary btn-xs']])
         ;
     }
