@@ -2,7 +2,7 @@
 
 namespace App\Form\Device;
 
-use App\Entity\Device;
+use App\Entity\Device\Device;
 use Symfony\Component\Form\AbstractType;
 use Symfony\Component\Form\Extension\Core\Type\SubmitType;
 use Symfony\Component\Form\Extension\Core\Type\TextType;
@@ -18,7 +18,7 @@ class DeviceHostnameType extends AbstractType
     public function buildForm(FormBuilderInterface $builder, array $options): void
     {
 
-        /** @var Device $device */
+        /** @var \App\Entity\Device\Device $device */
         $device = $options['data']['device'];
 
         $builder
