@@ -46,8 +46,8 @@ class DeviceSystemLabelType extends AbstractType
             ])
 
             ->add('save', SubmitType::class, [
-				'label' => '<i class="fas fa fa-ticket"></i> Set',
-				'label_html' => true,
+				'label' => 'Set',
+				'icon' => 'fas fa fa-ticket',
                 'block_prefix' => 'modal_footer'
 			])
         ;
