@@ -15,7 +15,8 @@ class LabelType extends AbstractType
      * @param FormBuilderInterface $builder
      * @param array $options
      */
-    public function buildForm(FormBuilderInterface $builder, array $options){
+    public function buildForm(FormBuilderInterface $builder, array $options): void
+	{
 
         $builder
             ->add('label', TextType::class, ['block_prefix' => 'modal_body'])
