@@ -16,7 +16,8 @@ class MonitoringGroupType extends AbstractType
      * @param FormBuilderInterface $builder
      * @param array $options
      */
-    public function buildForm(FormBuilderInterface $builder, array $options){
+    public function buildForm(FormBuilderInterface $builder, array $options): void
+	{
 
         $builder
             ->add('name', TextType::class, ['block_prefix' => 'modal_body'])
@@ -28,7 +29,8 @@ class MonitoringGroupType extends AbstractType
     /**
      * @param OptionsResolver $resolver
      */
-    public function configureOptions(OptionsResolver $resolver){
+    public function configureOptions(OptionsResolver $resolver): void
+	{
 
         $resolver->setDefaults([
             'data_class' => MonitoringGroup::class,
