@@ -13,7 +13,8 @@ class SystemLicenseApplyType extends AbstractType
      * @param FormBuilderInterface $builder
      * @param array $options
      */
-    public function buildForm(FormBuilderInterface $builder, array $options){
+    public function buildForm(FormBuilderInterface $builder, array $options): void
+	{
 
         $licenseFileName = $options['data']['licenseFileName'];
         $useForce = $options['data']['useForce'];
