@@ -9,6 +9,7 @@ use App\Entity\EventLog\EventSource;
 use App\Entity\EventLog\EventType;
 use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
 use Doctrine\Persistence\ManagerRegistry;
+use Symfony\Component\Security\Core\User\UserInterface;
 
 /**
  * @method EventLog|null find($id, $lockMode = null, $lockVersion = null)
@@ -38,40 +39,52 @@ class EventLogRepository extends ServiceEntityRepository
         $this->eventSourceRepository = $eventSourceRepository;
     }
 
-    /**
-     * @param string $entityName
-     * @param int $entityId
-     * @param string $action
-     * @param string|null $message
-     * @return EventLog
-     * @throws \Exception
-     */
+	/**
+	 * @param string $entityName
+	 * @param UserInterface $user
+	 * @param int|null $entityId
+	 * @param string|null $action
+	 * @param string|null $message
+	 * @param int|null $extraId
+	 * @return EventLog
+	 */
     public function addEventLog(
         string $entityName,
-        int $entityId,
-        string $action,
-        string $message = null,
-        int $extraId = null,
+		UserInterface $user,
+		?int $entityId = null,
+		?string $message = null,
+		?string $action = null,
+        ?int $extraId = null,
     ): EventLog {
 
         if (!$message) {
             if ($entityName === Alert::class) {
-                $eventTypeName = EventType::ALERT_CONFIG_UPDATE;
+                $eventTypeName = EventType::UI_ALERT_CONFIG_UPDATE_EVENT_TYPE_NAME;
                 $message = sprintf(self::MESSAGE_ALERT_ENTITY, $action);
-            } else {
-                throw new \RuntimeException('Not valid entity type given.');
+            //} else {
+             //   throw new \RuntimeException('Not valid entity type given.');
             }
         }
 
         if ($entityName === FwFileName::class) {
-            $eventTypeName = EventType::FW_FILE_UPLOADED;
+            $eventTypeName = EventType::UI_FW_FILE_UPLOADED_EVENT_TYPE_NAME;
         }
 
+		if(empty($eventTypeName)){
+			$eventTypeName = $entityName;
+		}
+
         $eventType = $this->eventTypeRepository->findOneBy(['name' => $eventTypeName]);
+		if(!$eventType){
+			throw new \RuntimeException('Invalid evenTypeName given: ' . $eventTypeName);
+		}
         $eventSource = $this->eventSourceRepository->findOneBy(['id' => EventSource::APP_WEBUI]);
         $eventLog = new EventLog();
         $eventLog->setEventType($eventType);
-        $eventLog->setValue($entityId);
+        $eventLog->setUser($user);
+        if($entityId){
+			$eventLog->setValue($entityId);
+		}
         $eventLog->setSource($eventSource);
         $eventLog->setExtraId($extraId);
         $eventLog->setMsg($message);
