@@ -26,7 +26,8 @@ class SimCardRepository extends ServiceEntityRepository
 
     public function findAllActiveSimCards(): array {
 
-        $qb = $this->_em->createQueryBuilder();
+		$em = $this->getEntityManager();
+        $qb = $em->createQueryBuilder();
 
         return $this->createQueryBuilder('sc')
             ->where($qb->expr()->isNotNull('sc.msisdn'))
