@@ -196,7 +196,7 @@ class ApiService
 
 	/**
 	 * @param string $url
-	 * @param array $jsonData
+	 * @param string|null $jsonData
 	 * @param bool $returnException
 	 * @param bool $throwRequestException
 	 * @param int $timeout
@@ -204,11 +204,10 @@ class ApiService
 	 * @throws TransportExceptionInterface
 	 * @throws \JsonException
 	 * @throws \Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface
-	 * @throws \Symfony\Contracts\HttpClient\Exception\DecodingExceptionInterface
 	 * @throws \Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface
 	 * @throws \Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface
 	 */
-	protected function postApiCall(string $url, string $jsonData = null,
+	protected function postApiCall(string $url, ?string $jsonData = null,
 								   bool $returnException = false, bool $throwRequestException = true,
 								   int $timeout = self::HTTP_CLIENT_REQUEST_DEFAULT_TIMEOUT): mixed
 	{
@@ -265,7 +264,7 @@ class ApiService
 			//dump($code);
 			//dump($response);
 
-			$data = json_decode($response);
+			//$data = json_decode($response);
 			//dump($data);
 			//die('tas');
 
